/*
 * See the dyninst/COPYRIGHT file for copyright information.
 *
 * We provide the Paradyn Tools (below described as "Paradyn")
 * on an AS IS basis, and do not warrant its validity or performance.
 * We reserve the right to update, modify, or discontinue this
 * software at any time.  We shall have no obligation to supply such
 * updates or modifications or any other form of support to you.
 *
 * By your use of Paradyn, you understand and agree that we (or any
 * other person or entity with proprietary rights in Paradyn) are
 * under no obligation to provide either maintenance services,
 * update services, notices of latent defects, or correction of
 * defects for Paradyn.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 */

#include "dataflowAPI/src/RegisterMap.h"
#include "dyn_regs.h"

// We use the singleton approach, rather than static construction, to ensure the
// register maps are created correctly. In at least one case (Ubuntu 12.04) they
// weren't.

namespace Dyninst {
namespace DataflowAPI {

RegisterMap &machRegIndex_x86() {
   static dyn_tls RegisterMap* mrmap = NULL;
   if (mrmap == NULL) {
      mrmap = new RegisterMap();
      *mrmap = {
         {x86::eax, 0},
         {x86::ecx, 1},
         {x86::edx, 2},
         {x86::ebx, 3},
         {x86::esp, 4},
         {x86::ebp, 5},
         {x86::esi, 6},
         {x86::edi, 7},
         {x86::eip, 8},
         {x86::cf, 9},
         {x86::flag1, 10},
         {x86::pf, 11},
         {x86::flag3, 12},
         {x86::af, 13},
         {x86::flag5, 14},
         {x86::zf, 15},
         {x86::sf, 16},
         {x86::tf, 17},
         {x86::if_, 18},
         {x86::df, 19},
         {x86::of, 20},
         {x86::flagc, 21},
         {x86::flagd, 22},
         {x86::nt_, 23},
         {x86::flagf, 24},
         {x86::rf, 25},
         {x86::ds, 26},
         {x86::es, 27},
         {x86::fs, 28},
         {x86::gs, 29},
         {x86::cs, 30},
         {x86::ss, 31},
         {x86::oeax, 32},
         {x86::fsbase, 33},
         {x86::gsbase, 34},
         {x86::k0, 35},
         {x86::k1, 36},
         {x86::k2, 37},
         {x86::k3, 38},
         {x86::k4, 39},
         {x86::k5, 40},
         {x86::k6, 41},
         {x86::k7, 42},
         {x86::zmm0, 43},
         {x86::zmm1, 44},
         {x86::zmm2, 45},
         {x86::zmm3, 46},
         {x86::zmm4, 47},
         {x86::zmm5, 48},
         {x86::zmm6, 49},
         {x86::zmm7, 50},
         {x86::ymm0, 75},
         {x86::ymm1, 76},
         {x86::ymm2, 77},
         {x86::ymm3, 78},
         {x86::ymm4, 79},
         {x86::ymm5, 80},
         {x86::ymm6, 81},
         {x86::ymm7, 82},
         {x86::xmm0, 107},
         {x86::xmm1, 108},
         {x86::xmm2, 109},
         {x86::xmm3, 110},
         {x86::xmm4, 111},
         {x86::xmm5, 112},
         {x86::xmm6, 113},
         {x86::xmm7, 114},
         {x86::mm0, 139},  // mm0 to mm7 and st0 to st7 collapse to mm0
         {x86::cr0, 140},
         {x86::cr1, 141},
         {x86::cr2, 142},
         {x86::cr3, 143},
         {x86::cr4, 144},
         {x86::cr5, 145},
         {x86::cr6, 146},
         {x86::cr7, 147},
         {x86::dr0, 148},
         {x86::dr1, 149},
         {x86::dr2, 150},
         {x86::dr3, 151},
         {x86::dr4, 152},
         {x86::dr5, 153},
         {x86::dr6, 154},
         {x86::dr7, 155},
         {x86::tr0, 156},
         {x86::tr1, 157},
         {x86::tr2, 158},
         {x86::tr3, 159},
         {x86::tr4, 160},
         {x86::tr5, 161},
         {x86::tr6, 162},
         {x86::tr7, 163} };
   }
   return *mrmap;
}

RegisterMap &machRegIndex_x86_64() {
   static dyn_tls RegisterMap* mrmap = NULL;
   if (mrmap == NULL) {
      mrmap = new RegisterMap();
      *mrmap = {
         {x86_64::rax, 0},
         {x86_64::rcx, 1},
         {x86_64::rdx, 2},
         {x86_64::rbx, 3},
         {x86_64::rsp, 4},
         {x86_64::rbp, 5},
         {x86_64::rsi, 6},
         {x86_64::rdi, 7},
         {x86_64::r8, 8},
         {x86_64::r9, 9},
         {x86_64::r10, 10},
         {x86_64::r11, 11},
         {x86_64::r12, 12},
         {x86_64::r13, 13},
         {x86_64::r14, 14},
         {x86_64::r15, 15},
         {x86_64::rip, 16},
         {x86_64::cf, 17},
         {x86_64::pf, 18},
         {x86_64::af, 19},
         {x86_64::zf, 20},
         {x86_64::sf, 21},
         {x86_64::tf, 22},
         {x86_64::if_, 23},
         {x86_64::df, 24},
         {x86_64::of, 25},
         {x86_64::nt_, 26},
         {x86_64::rf, 27},
         {x86_64::ds, 28},
         {x86_64::es, 29},
         {x86_64::fs, 30},
         {x86_64::gs, 31},
         {x86_64::cs, 32},
         {x86_64::ss, 33},
         {x86_64::orax, 34},
         {x86_64::fsbase, 35},
         {x86_64::gsbase, 36},
         {x86_64::k0, 37},
         {x86_64::k1, 38},
         {x86_64::k2, 39},
         {x86_64::k3, 40},
         {x86_64::k4, 41},
         {x86_64::k5, 42},
         {x86_64::k6, 43},
         {x86_64::k7, 44},
         {x86_64::zmm0, 45},
         {x86_64::zmm1, 46},
         {x86_64::zmm2, 47},
         {x86_64::zmm3, 48},
         {x86_64::zmm4, 49},
         {x86_64::zmm5, 50},
         {x86_64::zmm6, 51},
         {x86_64::zmm7, 52},
         {x86_64::zmm8, 53},
         {x86_64::zmm9, 54},
         {x86_64::zmm10, 55},
         {x86_64::zmm11, 56},
         {x86_64::zmm12, 57},
         {x86_64::zmm13, 58},
         {x86_64::zmm14, 59},
         {x86_64::zmm15, 60},
         {x86_64::zmm16, 61},
         {x86_64::zmm17, 62},
         {x86_64::zmm18, 63},
         {x86_64::zmm19, 64},
         {x86_64::zmm20, 65},
         {x86_64::zmm21, 66},
         {x86_64::zmm22, 67},
         {x86_64::zmm23, 68},
         {x86_64::zmm24, 69},
         {x86_64::zmm25, 70},
         {x86_64::zmm26, 71},
         {x86_64::zmm27, 72},
         {x86_64::zmm28, 73},
         {x86_64::zmm29, 74},
         {x86_64::zmm30, 75},
         {x86_64::zmm31, 76},
         {x86_64::ymm0, 77},
         {x86_64::ymm1, 78},
         {x86_64::ymm2, 79},
         {x86_64::ymm3, 80},
         {x86_64::ymm4, 81},
         {x86_64::ymm5, 82},
         {x86_64::ymm6, 83},
         {x86_64::ymm7, 84},
         {x86_64::ymm8, 85},
         {x86_64::ymm9, 86},
         {x86_64::ymm10, 87},
         {x86_64::ymm11, 88},
         {x86_64::ymm12, 89},
         {x86_64::ymm13, 90},
         {x86_64::ymm14, 91},
         {x86_64::ymm15, 92},
         {x86_64::ymm16, 93},
         {x86_64::ymm17, 94},
         {x86_64::ymm18, 95},
         {x86_64::ymm19, 96},
         {x86_64::ymm20, 97},
         {x86_64::ymm21, 98},
         {x86_64::ymm22, 99},
         {x86_64::ymm23, 100},
         {x86_64::ymm24, 101},
         {x86_64::ymm25, 102},
         {x86_64::ymm26, 103},
         {x86_64::ymm27, 104},
         {x86_64::ymm28, 105},
         {x86_64::ymm29, 106},
         {x86_64::ymm30, 107},
         {x86_64::ymm31, 108},
         {x86_64::xmm0, 109},
         {x86_64::xmm1, 110},
         {x86_64::xmm2, 111},
         {x86_64::xmm3, 112},
         {x86_64::xmm4, 113},
         {x86_64::xmm5, 114},
         {x86_64::xmm6, 115},
         {x86_64::xmm7, 116},
         {x86_64::xmm8, 117},
         {x86_64::xmm9, 118},
         {x86_64::xmm10, 119},
         {x86_64::xmm11, 120},
         {x86_64::xmm12, 121},
         {x86_64::xmm13, 122},
         {x86_64::xmm14, 123},
         {x86_64::xmm15, 124},
         {x86_64::xmm16, 125},
         {x86_64::xmm17, 126},
         {x86_64::xmm18, 127},
         {x86_64::xmm19, 128},
         {x86_64::xmm20, 129},
         {x86_64::xmm21, 130},
         {x86_64::xmm22, 131},
         {x86_64::xmm23, 132},
         {x86_64::xmm24, 133},
         {x86_64::xmm25, 134},
         {x86_64::xmm26, 135},
         {x86_64::xmm27, 136},
         {x86_64::xmm28, 137},
         {x86_64::xmm29, 138},
         {x86_64::xmm30, 139},
         {x86_64::xmm31, 140},
         {x86_64::mm0, 141}, // mm0 to mm7 and st0 to st7 collapse to mm0
         {x86_64::cr0, 142},
         {x86_64::cr1, 143},
         {x86_64::cr2, 144},
         {x86_64::cr3, 145},
         {x86_64::cr4, 146},
         {x86_64::cr5, 147},
         {x86_64::cr6, 148},
         {x86_64::cr7, 149},
         {x86_64::dr0, 150},
         {x86_64::dr1, 151},
         {x86_64::dr2, 152},
         {x86_64::dr3, 153},
         {x86_64::dr4, 154},
         {x86_64::dr5, 155},
         {x86_64::dr6, 156},
         {x86_64::dr7, 157},
         {x86_64::tr0, 158},
         {x86_64::tr1, 159},
         {x86_64::tr2, 160},
         {x86_64::tr3, 161},
         {x86_64::tr4, 162},
         {x86_64::tr5, 163},
         {x86_64::tr6, 164},
         {x86_64::tr7, 165},
      };
   }
   return *mrmap;
}

RegisterMap &machRegIndex_ppc() {
   static dyn_tls RegisterMap* mrmap = NULL;
   if (mrmap == NULL) {
      mrmap = new RegisterMap();
      *mrmap = {
         {ppc32::r0, 0},
         {ppc32::r1, 1},
         {ppc32::r2, 2},
         {ppc32::r3, 3},
         {ppc32::r4, 4},
         {ppc32::r5, 5},
         {ppc32::r6, 6},
         {ppc32::r7, 7},
         {ppc32::r8, 8},
         {ppc32::r9, 9},
         {ppc32::r10, 10},
         {ppc32::r11, 11},
         {ppc32::r12, 12},
         {ppc32::r13, 13},
         {ppc32::r14, 14},
         {ppc32::r15, 15},
         {ppc32::r16, 16},
         {ppc32::r17, 17},
         {ppc32::r18, 18},
         {ppc32::r19, 19},
         {ppc32::r20, 20},
         {ppc32::r21, 21},
         {ppc32::r22, 22},
         {ppc32::r23, 23},
         {ppc32::r24, 24},
         {ppc32::r25, 25},
         {ppc32::r26, 26},
         {ppc32::r27, 27},
         {ppc32::r28, 28},
         {ppc32::r29, 29},
         {ppc32::r30, 30},
         {ppc32::r31, 31},
         {ppc32::fpr0, 32},
         {ppc32::fpr1, 33},
         {ppc32::fpr2, 34},
         {ppc32::fpr3, 35},
         {ppc32::fpr4, 36},
         {ppc32::fpr5, 37},
         {ppc32::fpr6, 38},
         {ppc32::fpr7, 39},
         {ppc32::fpr8, 40},
         {ppc32::fpr9, 41},
         {ppc32::fpr10, 42},
         {ppc32::fpr11, 43},
         {ppc32::fpr12, 44},
         {ppc32::fpr13, 45},
         {ppc32::fpr14, 46},
         {ppc32::fpr15, 47},
         {ppc32::fpr16, 48},
         {ppc32::fpr17, 49},
         {ppc32::fpr18, 50},
         {ppc32::fpr19, 51},
         {ppc32::fpr20, 52},
         {ppc32::fpr21, 53},
         {ppc32::fpr22, 54},
         {ppc32::fpr23, 55},
         {ppc32::fpr24, 56},
         {ppc32::fpr25, 57},
         {ppc32::fpr26, 58},
         {ppc32::fpr27, 59},
         {ppc32::fpr28, 60},
         {ppc32::fpr29, 61},
         {ppc32::fpr30, 62},
         {ppc32::fpr31, 63},
         {ppc32::fsr0, 64},
         {ppc32::fsr1, 65},
         {ppc32::fsr2, 66},
         {ppc32::fsr3, 67},
         {ppc32::fsr4, 68},
         {ppc32::fsr5, 69},
         {ppc32::fsr6, 70},
         {ppc32::fsr7, 71},
         {ppc32::fsr8, 72},
         {ppc32::fsr9, 73},
         {ppc32::fsr10, 74},
         {ppc32::fsr11, 75},
         {ppc32::fsr12, 76},
         {ppc32::fsr13, 77},
         {ppc32::fsr14, 78},
         {ppc32::fsr15, 79},
         {ppc32::fsr16, 80},
         {ppc32::fsr17, 81},
         {ppc32::fsr18, 82},
         {ppc32::fsr19, 83},
         {ppc32::fsr20, 84},
         {ppc32::fsr21, 85},
         {ppc32::fsr22, 86},
         {ppc32::fsr23, 87},
         {ppc32::fsr24, 88},
         {ppc32::fsr25, 89},
         {ppc32::fsr26, 90},
         {ppc32::fsr27, 91},
         {ppc32::fsr28, 92},
         {ppc32::fsr29, 93},
         {ppc32::fsr30, 94},
         {ppc32::fsr31, 95},
         {ppc32::mq, 96},
         {ppc32::xer, 97},
         {ppc32::lr, 98},
         {ppc32::ctr, 99},
         {ppc32::dsisr, 100},
         {ppc32::dar, 101},
         {ppc32::dec, 102},
         {ppc32::sdr1, 103},
         {ppc32::srr0, 104},
         {ppc32::srr1, 105},
         {ppc32::sprg0, 106},
         {ppc32::sprg1, 107},
         {ppc32::sprg2, 108},
         {ppc32::sprg3, 109},
         {ppc32::sprg3_ro, 109},
         {ppc32::ear, 110},
         {ppc32::tbl_wo, 111},
         {ppc32::tbl_ro, 111},
         {ppc32::tbu_wo, 112},
         {ppc32::tbu_ro, 112},
         {ppc32::pvr, 113},
         {ppc32::ibat0u, 114},
         {ppc32::ibat0l, 115},
         {ppc32::ibat1u, 116},
         {ppc32::ibat1l, 117},
         {ppc32::ibat2u, 118},
         {ppc32::ibat2l, 119},
         {ppc32::ibat3u, 120},
         {ppc32::ibat3l, 121},
         {ppc32::dbat0u, 122},
         {ppc32::dbat0l, 123},
         {ppc32::dbat1u, 124},
         {ppc32::dbat1l, 125},
         {ppc32::dbat2u, 126},
         {ppc32::dbat2l, 127},
         {ppc32::dbat3u, 128},
         {ppc32::dbat3l, 129},
         {ppc32::pc, 130},
         {ppc32::fpscw, 131},
         {ppc32::fpscw0, 132},
         {ppc32::fpscw1, 133},
         {ppc32::fpscw2, 134},
         {ppc32::fpscw3, 135},
         {ppc32::fpscw4, 136},
         {ppc32::fpscw5, 137},
         {ppc32::fpscw6, 138},
         {ppc32::fpscw7, 139},
         {ppc32::msr, 140},
         {ppc32::ivpr, 141},
         {ppc32::ivor8, 142},
         {ppc32::seg0, 143},
         {ppc32::seg1, 144},
         {ppc32::seg2, 145},
         {ppc32::seg3, 146},
         {ppc32::seg4, 147},
         {ppc32::seg5, 148},
         {ppc32::seg6, 149},
         {ppc32::seg7, 150},
         {ppc32::cr0, 151},
         {ppc32::cr1, 152},
         {ppc32::cr2, 153},
         {ppc32::cr3, 154},
         {ppc32::cr4, 155},
         {ppc32::cr5, 156},
         {ppc32::cr6, 157},
         {ppc32::cr7, 158},
         {ppc32::cr, 159},
         {ppc32::sprg4, 160},
         {ppc32::sprg4_ro, 160},
         {ppc32::sprg5, 161},
         {ppc32::sprg5_ro, 161},
         {ppc32::sprg6, 162},
         {ppc32::sprg6_ro, 162},
         {ppc32::sprg7, 163},
         {ppc32::sprg7_ro, 163}
   };
   }
   return *mrmap;
}

RegisterMap &machRegIndex_ppc_64() {
   static dyn_tls RegisterMap* mrmap = NULL;
   if (mrmap == NULL) {
      mrmap = new RegisterMap();
      *mrmap = {
         {ppc64::r0, 0},
         {ppc64::r1, 1},
         {ppc64::r2, 2},
         {ppc64::r3, 3},
         {ppc64::r4, 4},
         {ppc64::r5, 5},
         {ppc64::r6, 6},
         {ppc64::r7, 7},
         {ppc64::r8, 8},
         {ppc64::r9, 9},
         {ppc64::r10, 10},
         {ppc64::r11, 11},
         {ppc64::r12, 12},
         {ppc64::r13, 13},
         {ppc64::r14, 14},
         {ppc64::r15, 15},
         {ppc64::r16, 16},
         {ppc64::r17, 17},
         {ppc64::r18, 18},
         {ppc64::r19, 19},
         {ppc64::r20, 20},
         {ppc64::r21, 21},
         {ppc64::r22, 22},
         {ppc64::r23, 23},
         {ppc64::r24, 24},
         {ppc64::r25, 25},
         {ppc64::r26, 26},
         {ppc64::r27, 27},
         {ppc64::r28, 28},
         {ppc64::r29, 29},
         {ppc64::r30, 30},
         {ppc64::r31, 31},
         {ppc64::fpr0, 32},
         {ppc64::fpr1, 33},
         {ppc64::fpr2, 34},
         {ppc64::fpr3, 35},
         {ppc64::fpr4, 36},
         {ppc64::fpr5, 37},
         {ppc64::fpr6, 38},
         {ppc64::fpr7, 39},
         {ppc64::fpr8, 40},
         {ppc64::fpr9, 41},
         {ppc64::fpr10, 42},
         {ppc64::fpr11, 43},
         {ppc64::fpr12, 44},
         {ppc64::fpr13, 45},
         {ppc64::fpr14, 46},
         {ppc64::fpr15, 47},
         {ppc64::fpr16, 48},
         {ppc64::fpr17, 49},
         {ppc64::fpr18, 50},
         {ppc64::fpr19, 51},
         {ppc64::fpr20, 52},
         {ppc64::fpr21, 53},
         {ppc64::fpr22, 54},
         {ppc64::fpr23, 55},
         {ppc64::fpr24, 56},
         {ppc64::fpr25, 57},
         {ppc64::fpr26, 58},
         {ppc64::fpr27, 59},
         {ppc64::fpr28, 60},
         {ppc64::fpr29, 61},
         {ppc64::fpr30, 62},
         {ppc64::fpr31, 63},
         {ppc64::fsr0, 64},
         {ppc64::fsr1, 65},
         {ppc64::fsr2, 66},
         {ppc64::fsr3, 67},
         {ppc64::fsr4, 68},
         {ppc64::fsr5, 69},
         {ppc64::fsr6, 70},
         {ppc64::fsr7, 71},
         {ppc64::fsr8, 72},
         {ppc64::fsr9, 73},
         {ppc64::fsr10, 74},
         {ppc64::fsr11, 75},
         {ppc64::fsr12, 76},
         {ppc64::fsr13, 77},
         {ppc64::fsr14, 78},
         {ppc64::fsr15, 79},
         {ppc64::fsr16, 80},
         {ppc64::fsr17, 81},
         {ppc64::fsr18, 82},
         {ppc64::fsr19, 83},
         {ppc64::fsr20, 84},
         {ppc64::fsr21, 85},
         {ppc64::fsr22, 86},
         {ppc64::fsr23, 87},
         {ppc64::fsr24, 88},
         {ppc64::fsr25, 89},
         {ppc64::fsr26, 90},
         {ppc64::fsr27, 91},
         {ppc64::fsr28, 92},
         {ppc64::fsr29, 93},
         {ppc64::fsr30, 94},
         {ppc64::fsr31, 95},
         {ppc64::mq, 96},
         {ppc64::xer, 97},
         {ppc64::lr, 98},
         {ppc64::ctr, 99},
         {ppc64::dsisr, 100},
         {ppc64::dar, 101},
         {ppc64::dec, 102},
         {ppc64::sdr1, 103},
         {ppc64::srr0, 104},
         {ppc64::srr1, 105},
         {ppc64::sprg0, 106},
         {ppc64::sprg1, 107},
         {ppc64::sprg2, 108},
         {ppc64::sprg3, 109},
         {ppc64::sprg3_ro, 109},
         {ppc64::ear, 110},
         {ppc64::tbl_wo, 111},
         {ppc64::tbl_ro, 111},
         {ppc64::tbu_wo, 112},
         {ppc64::tbu_ro, 112},
         {ppc64::pvr, 113},
         {ppc64::ibat0u, 114},
         {ppc64::ibat0l, 115},
         {ppc64::ibat1u, 116},
         {ppc64::ibat1l, 117},
         {ppc64::ibat2u, 118},
         {ppc64::ibat2l, 119},
         {ppc64::ibat3u, 120},
         {ppc64::ibat3l, 121},
         {ppc64::dbat0u, 122},
         {ppc64::dbat0l, 123},
         {ppc64::dbat1u, 124},
         {ppc64::dbat1l, 125},
         {ppc64::dbat2u, 126},
         {ppc64::dbat2l, 127},
         {ppc64::dbat3u, 128},
         {ppc64::dbat3l, 129},
         {ppc64::pc, 130},
         {ppc64::fpscw, 131},
         {ppc64::fpscw0, 132},
         {ppc64::fpscw1, 133},
         {ppc64::fpscw2, 134},
         {ppc64::fpscw3, 135},
         {ppc64::fpscw4, 136},
         {ppc64::fpscw5, 137},
         {ppc64::fpscw6, 138},
         {ppc64::fpscw7, 139},
         {ppc64::msr, 140},
         {ppc64::ivpr, 141},
         {ppc64::ivor8, 142},
         {ppc64::seg0, 143},
         {ppc64::seg1, 144},
         {ppc64::seg2, 145},
         {ppc64::seg3, 146},
         {ppc64::seg4, 147},
         {ppc64::seg5, 148},
         {ppc64::seg6, 149},
         {ppc64::seg7, 150},
         {ppc64::cr0, 151},
         {ppc64::cr1, 152},
         {ppc64::cr2, 153},
         {ppc64::cr3, 154},
         {ppc64::cr4, 155},
         {ppc64::cr5, 156},
         {ppc64::cr6, 157},
         {ppc64::cr7, 158},
         {ppc64::cr, 159},
         {ppc64::sprg4, 160},
         {ppc64::sprg4_ro, 160},
         {ppc64::sprg5, 161},
         {ppc64::sprg5_ro, 161},
         {ppc64::sprg6, 162},
         {ppc64::sprg6_ro, 162},
         {ppc64::sprg7, 163},
         {ppc64::sprg7_ro, 163}
   };
   }
   return *mrmap;
}

RegisterMap &machRegIndex_aarch64() {
   static dyn_tls RegisterMap* mrmap = NULL;
   if (mrmap == NULL) {
      mrmap = new RegisterMap();
      *mrmap = {
	 {aarch64::x0, 0},
	 {aarch64::x1, 1},
	 {aarch64::x2, 2},
	 {aarch64::x3, 3},
	 {aarch64::x4, 4},
	 {aarch64::x5, 5},
	 {aarch64::x6, 6},
	 {aarch64::x7, 7},
	 {aarch64::x8, 8},
	 {aarch64::x9, 9},
	 {aarch64::x10, 10},
	 {aarch64::x11, 11},
	 {aarch64::x12, 12},
	 {aarch64::x13, 13},
	 {aarch64::x14, 14},
	 {aarch64::x15, 15},
	 {aarch64::x16, 16},
	 {aarch64::x17, 17},
	 {aarch64::x18, 18},
	 {aarch64::x19, 19},
	 {aarch64::x20, 20},
	 {aarch64::x21, 21},
	 {aarch64::x22, 22},
	 {aarch64::x23, 23},
	 {aarch64::x24, 24},
	 {aarch64::x25, 25},
	 {aarch64::x26, 26},
	 {aarch64::x27, 27},
	 {aarch64::x28, 28},
	 {aarch64::x29, 29},
     {aarch64::x30, 30},
     {aarch64::w0, 0},
     {aarch64::w1, 1},
     {aarch64::w2, 2},
     {aarch64::w3, 3},
     {aarch64::w4, 4},
     {aarch64::w5, 5},
     {aarch64::w6, 6},
     {aarch64::w7, 7},
     {aarch64::w8, 8},
     {aarch64::w9, 9},
     {aarch64::w10, 10},
     {aarch64::w11, 11},
     {aarch64::w12, 12},
     {aarch64::w13, 13},
     {aarch64::w14, 14},
     {aarch64::w15, 15},
     {aarch64::w16, 16},
     {aarch64::w17, 17},
     {aarch64::w18, 18},
     {aarch64::w19, 19},
     {aarch64::w20, 20},
     {aarch64::w21, 21},
     {aarch64::w22, 22},
     {aarch64::w23, 23},
     {aarch64::w24, 24},
     {aarch64::w25, 25},
     {aarch64::w26, 26},
     {aarch64::w27, 27},
     {aarch64::w28, 28},
     {aarch64::w29, 29},
     {aarch64::w30, 30},
     {aarch64::q0,  31},
     {aarch64::q1,  32},
     {aarch64::q2,  33},
     {aarch64::q3,  34},
     {aarch64::q4,  35},
     {aarch64::q5,  36},
     {aarch64::q6,  37},
     {aarch64::q7,  38},
     {aarch64::q8,  39},
     {aarch64::q9,  40},
     {aarch64::q10, 41},
     {aarch64::q11, 42},
     {aarch64::q12, 43},
     {aarch64::q13, 44},
     {aarch64::q14, 45},
     {aarch64::q15, 46},
     {aarch64::q16, 47},
     {aarch64::q17, 48},
     {aarch64::q18, 49},
     {aarch64::q19, 50},
     {aarch64::q20, 51},
     {aarch64::q21, 52},
     {aarch64::q22, 53},
     {aarch64::q23, 54},
     {aarch64::q24, 55},
     {aarch64::q25, 56},
     {aarch64::q26, 57},
     {aarch64::q27, 58},
     {aarch64::q28, 59},
     {aarch64::q29, 60},
     {aarch64::q30, 61},
     {aarch64::q31, 62},
     {aarch64::fpcr,63},
     {aarch64::fpsr,64},
     {aarch64::pc,  65},
     {aarch64::sp,  66},
     {aarch64::pstate, 67},
     {aarch64::xzr, 68}};
   }
   return *mrmap;
}

RegisterMap &machRegIndex_amdgpu_gfx908() {
   static dyn_tls RegisterMap* mrmap = NULL;
   if (mrmap == NULL) {
      mrmap = new RegisterMap();
      *mrmap = {
     {amdgpu_gfx908::s0,0},
     {amdgpu_gfx908::s1,1},
     {amdgpu_gfx908::s2,2},
     {amdgpu_gfx908::s3,3},
     {amdgpu_gfx908::s4,4},
     {amdgpu_gfx908::s5,5},
     {amdgpu_gfx908::s6,6},
     {amdgpu_gfx908::s7,7},
     {amdgpu_gfx908::s8,8},
     {amdgpu_gfx908::s9,9},
     {amdgpu_gfx908::s10,10},
     {amdgpu_gfx908::s11,11},
     {amdgpu_gfx908::s12,12},
     {amdgpu_gfx908::s13,13},
     {amdgpu_gfx908::s14,14},
     {amdgpu_gfx908::s15,15},
     {amdgpu_gfx908::s16,16},
     {amdgpu_gfx908::s17,17},
     {amdgpu_gfx908::s18,18},
     {amdgpu_gfx908::s19,19},
     {amdgpu_gfx908::s20,20},
     {amdgpu_gfx908::s21,21},
     {amdgpu_gfx908::s22,22},
     {amdgpu_gfx908::s23,23},
     {amdgpu_gfx908::s24,24},
     {amdgpu_gfx908::s25,25},
     {amdgpu_gfx908::s26,26},
     {amdgpu_gfx908::s27,27},
     {amdgpu_gfx908::s28,28},
     {amdgpu_gfx908::s29,29},
     {amdgpu_gfx908::s30,30},
     {amdgpu_gfx908::s31,31},
     {amdgpu_gfx908::s32,32},
     {amdgpu_gfx908::s33,33},
     {amdgpu_gfx908::s34,34},
     {amdgpu_gfx908::s35,35},
     {amdgpu_gfx908::s36,36},
     {amdgpu_gfx908::s37,37},
     {amdgpu_gfx908::s38,38},
     {amdgpu_gfx908::s39,39},
     {amdgpu_gfx908::s40,40},
     {amdgpu_gfx908::s41,41},
     {amdgpu_gfx908::s42,42},
     {amdgpu_gfx908::s43,43},
     {amdgpu_gfx908::s44,44},
     {amdgpu_gfx908::s45,45},
     {amdgpu_gfx908::s46,46},
     {amdgpu_gfx908::s47,47},
     {amdgpu_gfx908::s48,48},
     {amdgpu_gfx908::s49,49},
     {amdgpu_gfx908::s50,50},
     {amdgpu_gfx908::s51,51},
     {amdgpu_gfx908::s52,52},
     {amdgpu_gfx908::s53,53},
     {amdgpu_gfx908::s54,54},
     {amdgpu_gfx908::s55,55},
     {amdgpu_gfx908::s56,56},
     {amdgpu_gfx908::s57,57},
     {amdgpu_gfx908::s58,58},
     {amdgpu_gfx908::s59,59},
     {amdgpu_gfx908::s60,60},
     {amdgpu_gfx908::s61,61},
     {amdgpu_gfx908::s62,62},
     {amdgpu_gfx908::s63,63},
     {amdgpu_gfx908::s64,64},
     {amdgpu_gfx908::s65,65},
     {amdgpu_gfx908::s66,66},
     {amdgpu_gfx908::s67,67},
     {amdgpu_gfx908::s68,68},
     {amdgpu_gfx908::s69,69},
     {amdgpu_gfx908::s70,70},
     {amdgpu_gfx908::s71,71},
     {amdgpu_gfx908::s72,72},
     {amdgpu_gfx908::s73,73},
     {amdgpu_gfx908::s74,74},
     {amdgpu_gfx908::s75,75},
     {amdgpu_gfx908::s76,76},
     {amdgpu_gfx908::s77,77},
     {amdgpu_gfx908::s78,78},
     {amdgpu_gfx908::s79,79},
     {amdgpu_gfx908::s80,80},
     {amdgpu_gfx908::s81,81},
     {amdgpu_gfx908::s82,82},
     {amdgpu_gfx908::s83,83},
     {amdgpu_gfx908::s84,84},
     {amdgpu_gfx908::s85,85},
     {amdgpu_gfx908::s86,86},
     {amdgpu_gfx908::s87,87},
     {amdgpu_gfx908::s88,88},
     {amdgpu_gfx908::s89,89},
     {amdgpu_gfx908::s90,90},
     {amdgpu_gfx908::s91,91},
     {amdgpu_gfx908::s92,92},
     {amdgpu_gfx908::s93,93},
     {amdgpu_gfx908::s94,94},
     {amdgpu_gfx908::s95,95},
     {amdgpu_gfx908::s96,96},
     {amdgpu_gfx908::s97,97},
     {amdgpu_gfx908::s98,98},
     {amdgpu_gfx908::s99,99},
     {amdgpu_gfx908::s100,100},
     {amdgpu_gfx908::s101,101},
     {amdgpu_gfx908::flat_scratch_lo,102},
     {amdgpu_gfx908::flat_scratch_hi,103},
     {amdgpu_gfx908::xnack_mask_lo,104},
     {amdgpu_gfx908::xnack_mask_hi,105},
     {amdgpu_gfx908::vcc_lo,106},
     {amdgpu_gfx908::vcc_hi,107},
     {amdgpu_gfx908::v0,108},
     {amdgpu_gfx908::v1,109},
     {amdgpu_gfx908::v2,110},
     {amdgpu_gfx908::v3,111},
     {amdgpu_gfx908::v4,112},
     {amdgpu_gfx908::v5,113},
     {amdgpu_gfx908::v6,114},
     {amdgpu_gfx908::v7,115},
     {amdgpu_gfx908::v8,116},
     {amdgpu_gfx908::v9,117},
     {amdgpu_gfx908::v10,118},
     {amdgpu_gfx908::v11,119},
     {amdgpu_gfx908::v12,120},
     {amdgpu_gfx908::v13,121},
     {amdgpu_gfx908::v14,122},
     {amdgpu_gfx908::v15,123},
     {amdgpu_gfx908::v16,124},
     {amdgpu_gfx908::v17,125},
     {amdgpu_gfx908::v18,126},
     {amdgpu_gfx908::v19,127},
     {amdgpu_gfx908::v20,128},
     {amdgpu_gfx908::v21,129},
     {amdgpu_gfx908::v22,130},
     {amdgpu_gfx908::v23,131},
     {amdgpu_gfx908::v24,132},
     {amdgpu_gfx908::v25,133},
     {amdgpu_gfx908::v26,134},
     {amdgpu_gfx908::v27,135},
     {amdgpu_gfx908::v28,136},
     {amdgpu_gfx908::v29,137},
     {amdgpu_gfx908::v30,138},
     {amdgpu_gfx908::v31,139},
     {amdgpu_gfx908::v32,140},
     {amdgpu_gfx908::v33,141},
     {amdgpu_gfx908::v34,142},
     {amdgpu_gfx908::v35,143},
     {amdgpu_gfx908::v36,144},
     {amdgpu_gfx908::v37,145},
     {amdgpu_gfx908::v38,146},
     {amdgpu_gfx908::v39,147},
     {amdgpu_gfx908::v40,148},
     {amdgpu_gfx908::v41,149},
     {amdgpu_gfx908::v42,150},
     {amdgpu_gfx908::v43,151},
     {amdgpu_gfx908::v44,152},
     {amdgpu_gfx908::v45,153},
     {amdgpu_gfx908::v46,154},
     {amdgpu_gfx908::v47,155},
     {amdgpu_gfx908::v48,156},
     {amdgpu_gfx908::v49,157},
     {amdgpu_gfx908::v50,158},
     {amdgpu_gfx908::v51,159},
     {amdgpu_gfx908::v52,160},
     {amdgpu_gfx908::v53,161},
     {amdgpu_gfx908::v54,162},
     {amdgpu_gfx908::v55,163},
     {amdgpu_gfx908::v56,164},
     {amdgpu_gfx908::v57,165},
     {amdgpu_gfx908::v58,166},
     {amdgpu_gfx908::v59,167},
     {amdgpu_gfx908::v60,168},
     {amdgpu_gfx908::v61,169},
     {amdgpu_gfx908::v62,170},
     {amdgpu_gfx908::v63,171},
     {amdgpu_gfx908::v64,172},
     {amdgpu_gfx908::v65,173},
     {amdgpu_gfx908::v66,174},
     {amdgpu_gfx908::v67,175},
     {amdgpu_gfx908::v68,176},
     {amdgpu_gfx908::v69,177},
     {amdgpu_gfx908::v70,178},
     {amdgpu_gfx908::v71,179},
     {amdgpu_gfx908::v72,180},
     {amdgpu_gfx908::v73,181},
     {amdgpu_gfx908::v74,182},
     {amdgpu_gfx908::v75,183},
     {amdgpu_gfx908::v76,184},
     {amdgpu_gfx908::v77,185},
     {amdgpu_gfx908::v78,186},
     {amdgpu_gfx908::v79,187},
     {amdgpu_gfx908::v80,188},
     {amdgpu_gfx908::v81,189},
     {amdgpu_gfx908::v82,190},
     {amdgpu_gfx908::v83,191},
     {amdgpu_gfx908::v84,192},
     {amdgpu_gfx908::v85,193},
     {amdgpu_gfx908::v86,194},
     {amdgpu_gfx908::v87,195},
     {amdgpu_gfx908::v88,196},
     {amdgpu_gfx908::v89,197},
     {amdgpu_gfx908::v90,198},
     {amdgpu_gfx908::v91,199},
     {amdgpu_gfx908::v92,200},
     {amdgpu_gfx908::v93,201},
     {amdgpu_gfx908::v94,202},
     {amdgpu_gfx908::v95,203},
     {amdgpu_gfx908::v96,204},
     {amdgpu_gfx908::v97,205},
     {amdgpu_gfx908::v98,206},
     {amdgpu_gfx908::v99,207},
     {amdgpu_gfx908::v100,208},
     {amdgpu_gfx908::v101,209},
     {amdgpu_gfx908::v102,210},
     {amdgpu_gfx908::v103,211},
     {amdgpu_gfx908::v104,212},
     {amdgpu_gfx908::v105,213},
     {amdgpu_gfx908::v106,214},
     {amdgpu_gfx908::v107,215},
     {amdgpu_gfx908::v108,216},
     {amdgpu_gfx908::v109,217},
     {amdgpu_gfx908::v110,218},
     {amdgpu_gfx908::v111,219},
     {amdgpu_gfx908::v112,220},
     {amdgpu_gfx908::v113,221},
     {amdgpu_gfx908::v114,222},
     {amdgpu_gfx908::v115,223},
     {amdgpu_gfx908::v116,224},
     {amdgpu_gfx908::v117,225},
     {amdgpu_gfx908::v118,226},
     {amdgpu_gfx908::v119,227},
     {amdgpu_gfx908::v120,228},
     {amdgpu_gfx908::v121,229},
     {amdgpu_gfx908::v122,230},
     {amdgpu_gfx908::v123,231},
     {amdgpu_gfx908::v124,232},
     {amdgpu_gfx908::v125,233},
     {amdgpu_gfx908::v126,234},
     {amdgpu_gfx908::v127,235},
     {amdgpu_gfx908::v128,236},
     {amdgpu_gfx908::v129,237},
     {amdgpu_gfx908::v130,238},
     {amdgpu_gfx908::v131,239},
     {amdgpu_gfx908::v132,240},
     {amdgpu_gfx908::v133,241},
     {amdgpu_gfx908::v134,242},
     {amdgpu_gfx908::v135,243},
     {amdgpu_gfx908::v136,244},
     {amdgpu_gfx908::v137,245},
     {amdgpu_gfx908::v138,246},
     {amdgpu_gfx908::v139,247},
     {amdgpu_gfx908::v140,248},
     {amdgpu_gfx908::v141,249},
     {amdgpu_gfx908::v142,250},
     {amdgpu_gfx908::v143,251},
     {amdgpu_gfx908::v144,252},
     {amdgpu_gfx908::v145,253},
     {amdgpu_gfx908::v146,254},
     {amdgpu_gfx908::v147,255},
     {amdgpu_gfx908::v148,256},
     {amdgpu_gfx908::v149,257},
     {amdgpu_gfx908::v150,258},
     {amdgpu_gfx908::v151,259},
     {amdgpu_gfx908::v152,260},
     {amdgpu_gfx908::v153,261},
     {amdgpu_gfx908::v154,262},
     {amdgpu_gfx908::v155,263},
     {amdgpu_gfx908::v156,264},
     {amdgpu_gfx908::v157,265},
     {amdgpu_gfx908::v158,266},
     {amdgpu_gfx908::v159,267},
     {amdgpu_gfx908::v160,268},
     {amdgpu_gfx908::v161,269},
     {amdgpu_gfx908::v162,270},
     {amdgpu_gfx908::v163,271},
     {amdgpu_gfx908::v164,272},
     {amdgpu_gfx908::v165,273},
     {amdgpu_gfx908::v166,274},
     {amdgpu_gfx908::v167,275},
     {amdgpu_gfx908::v168,276},
     {amdgpu_gfx908::v169,277},
     {amdgpu_gfx908::v170,278},
     {amdgpu_gfx908::v171,279},
     {amdgpu_gfx908::v172,280},
     {amdgpu_gfx908::v173,281},
     {amdgpu_gfx908::v174,282},
     {amdgpu_gfx908::v175,283},
     {amdgpu_gfx908::v176,284},
     {amdgpu_gfx908::v177,285},
     {amdgpu_gfx908::v178,286},
     {amdgpu_gfx908::v179,287},
     {amdgpu_gfx908::v180,288},
     {amdgpu_gfx908::v181,289},
     {amdgpu_gfx908::v182,290},
     {amdgpu_gfx908::v183,291},
     {amdgpu_gfx908::v184,292},
     {amdgpu_gfx908::v185,293},
     {amdgpu_gfx908::v186,294},
     {amdgpu_gfx908::v187,295},
     {amdgpu_gfx908::v188,296},
     {amdgpu_gfx908::v189,297},
     {amdgpu_gfx908::v190,298},
     {amdgpu_gfx908::v191,299},
     {amdgpu_gfx908::v192,300},
     {amdgpu_gfx908::v193,301},
     {amdgpu_gfx908::v194,302},
     {amdgpu_gfx908::v195,303},
     {amdgpu_gfx908::v196,304},
     {amdgpu_gfx908::v197,305},
     {amdgpu_gfx908::v198,306},
     {amdgpu_gfx908::v199,307},
     {amdgpu_gfx908::v200,308},
     {amdgpu_gfx908::v201,309},
     {amdgpu_gfx908::v202,310},
     {amdgpu_gfx908::v203,311},
     {amdgpu_gfx908::v204,312},
     {amdgpu_gfx908::v205,313},
     {amdgpu_gfx908::v206,314},
     {amdgpu_gfx908::v207,315},
     {amdgpu_gfx908::v208,316},
     {amdgpu_gfx908::v209,317},
     {amdgpu_gfx908::v210,318},
     {amdgpu_gfx908::v211,319},
     {amdgpu_gfx908::v212,320},
     {amdgpu_gfx908::v213,321},
     {amdgpu_gfx908::v214,322},
     {amdgpu_gfx908::v215,323},
     {amdgpu_gfx908::v216,324},
     {amdgpu_gfx908::v217,325},
     {amdgpu_gfx908::v218,326},
     {amdgpu_gfx908::v219,327},
     {amdgpu_gfx908::v220,328},
     {amdgpu_gfx908::v221,329},
     {amdgpu_gfx908::v222,330},
     {amdgpu_gfx908::v223,331},
     {amdgpu_gfx908::v224,332},
     {amdgpu_gfx908::v225,333},
     {amdgpu_gfx908::v226,334},
     {amdgpu_gfx908::v227,335},
     {amdgpu_gfx908::v228,336},
     {amdgpu_gfx908::v229,337},
     {amdgpu_gfx908::v230,338},
     {amdgpu_gfx908::v231,339},
     {amdgpu_gfx908::v232,340},
     {amdgpu_gfx908::v233,341},
     {amdgpu_gfx908::v234,342},
     {amdgpu_gfx908::v235,343},
     {amdgpu_gfx908::v236,344},
     {amdgpu_gfx908::v237,345},
     {amdgpu_gfx908::v238,346},
     {amdgpu_gfx908::v239,347},
     {amdgpu_gfx908::v240,348},
     {amdgpu_gfx908::v241,349},
     {amdgpu_gfx908::v242,350},
     {amdgpu_gfx908::v243,351},
     {amdgpu_gfx908::v244,352},
     {amdgpu_gfx908::v245,353},
     {amdgpu_gfx908::v246,354},
     {amdgpu_gfx908::v247,355},
     {amdgpu_gfx908::v248,356},
     {amdgpu_gfx908::v249,357},
     {amdgpu_gfx908::v250,358},
     {amdgpu_gfx908::v251,359},
     {amdgpu_gfx908::v252,360},
     {amdgpu_gfx908::v253,361},
     {amdgpu_gfx908::v254,362},
     {amdgpu_gfx908::v255,363},
     {amdgpu_gfx908::acc0,364},
     {amdgpu_gfx908::acc1,365},
     {amdgpu_gfx908::acc2,366},
     {amdgpu_gfx908::acc3,367},
     {amdgpu_gfx908::acc4,368},
     {amdgpu_gfx908::acc5,369},
     {amdgpu_gfx908::acc6,370},
     {amdgpu_gfx908::acc7,371},
     {amdgpu_gfx908::acc8,372},
     {amdgpu_gfx908::acc9,373},
     {amdgpu_gfx908::acc10,374},
     {amdgpu_gfx908::acc11,375},
     {amdgpu_gfx908::acc12,376},
     {amdgpu_gfx908::acc13,377},
     {amdgpu_gfx908::acc14,378},
     {amdgpu_gfx908::acc15,379},
     {amdgpu_gfx908::acc16,380},
     {amdgpu_gfx908::acc17,381},
     {amdgpu_gfx908::acc18,382},
     {amdgpu_gfx908::acc19,383},
     {amdgpu_gfx908::acc20,384},
     {amdgpu_gfx908::acc21,385},
     {amdgpu_gfx908::acc22,386},
     {amdgpu_gfx908::acc23,387},
     {amdgpu_gfx908::acc24,388},
     {amdgpu_gfx908::acc25,389},
     {amdgpu_gfx908::acc26,390},
     {amdgpu_gfx908::acc27,391},
     {amdgpu_gfx908::acc28,392},
     {amdgpu_gfx908::acc29,393},
     {amdgpu_gfx908::acc30,394},
     {amdgpu_gfx908::acc31,395},
     {amdgpu_gfx908::acc32,396},
     {amdgpu_gfx908::acc33,397},
     {amdgpu_gfx908::acc34,398},
     {amdgpu_gfx908::acc35,399},
     {amdgpu_gfx908::acc36,400},
     {amdgpu_gfx908::acc37,401},
     {amdgpu_gfx908::acc38,402},
     {amdgpu_gfx908::acc39,403},
     {amdgpu_gfx908::acc40,404},
     {amdgpu_gfx908::acc41,405},
     {amdgpu_gfx908::acc42,406},
     {amdgpu_gfx908::acc43,407},
     {amdgpu_gfx908::acc44,408},
     {amdgpu_gfx908::acc45,409},
     {amdgpu_gfx908::acc46,410},
     {amdgpu_gfx908::acc47,411},
     {amdgpu_gfx908::acc48,412},
     {amdgpu_gfx908::acc49,413},
     {amdgpu_gfx908::acc50,414},
     {amdgpu_gfx908::acc51,415},
     {amdgpu_gfx908::acc52,416},
     {amdgpu_gfx908::acc53,417},
     {amdgpu_gfx908::acc54,418},
     {amdgpu_gfx908::acc55,419},
     {amdgpu_gfx908::acc56,420},
     {amdgpu_gfx908::acc57,421},
     {amdgpu_gfx908::acc58,422},
     {amdgpu_gfx908::acc59,423},
     {amdgpu_gfx908::acc60,424},
     {amdgpu_gfx908::acc61,425},
     {amdgpu_gfx908::acc62,426},
     {amdgpu_gfx908::acc63,427},
     {amdgpu_gfx908::acc64,428},
     {amdgpu_gfx908::acc65,429},
     {amdgpu_gfx908::acc66,430},
     {amdgpu_gfx908::acc67,431},
     {amdgpu_gfx908::acc68,432},
     {amdgpu_gfx908::acc69,433},
     {amdgpu_gfx908::acc70,434},
     {amdgpu_gfx908::acc71,435},
     {amdgpu_gfx908::acc72,436},
     {amdgpu_gfx908::acc73,437},
     {amdgpu_gfx908::acc74,438},
     {amdgpu_gfx908::acc75,439},
     {amdgpu_gfx908::acc76,440},
     {amdgpu_gfx908::acc77,441},
     {amdgpu_gfx908::acc78,442},
     {amdgpu_gfx908::acc79,443},
     {amdgpu_gfx908::acc80,444},
     {amdgpu_gfx908::acc81,445},
     {amdgpu_gfx908::acc82,446},
     {amdgpu_gfx908::acc83,447},
     {amdgpu_gfx908::acc84,448},
     {amdgpu_gfx908::acc85,449},
     {amdgpu_gfx908::acc86,450},
     {amdgpu_gfx908::acc87,451},
     {amdgpu_gfx908::acc88,452},
     {amdgpu_gfx908::acc89,453},
     {amdgpu_gfx908::acc90,454},
     {amdgpu_gfx908::acc91,455},
     {amdgpu_gfx908::acc92,456},
     {amdgpu_gfx908::acc93,457},
     {amdgpu_gfx908::acc94,458},
     {amdgpu_gfx908::acc95,459},
     {amdgpu_gfx908::acc96,460},
     {amdgpu_gfx908::acc97,461},
     {amdgpu_gfx908::acc98,462},
     {amdgpu_gfx908::acc99,463},
     {amdgpu_gfx908::acc100,464},
     {amdgpu_gfx908::acc101,465},
     {amdgpu_gfx908::acc102,466},
     {amdgpu_gfx908::acc103,467},
     {amdgpu_gfx908::acc104,468},
     {amdgpu_gfx908::acc105,469},
     {amdgpu_gfx908::acc106,470},
     {amdgpu_gfx908::acc107,471},
     {amdgpu_gfx908::acc108,472},
     {amdgpu_gfx908::acc109,473},
     {amdgpu_gfx908::acc110,474},
     {amdgpu_gfx908::acc111,475},
     {amdgpu_gfx908::acc112,476},
     {amdgpu_gfx908::acc113,477},
     {amdgpu_gfx908::acc114,478},
     {amdgpu_gfx908::acc115,479},
     {amdgpu_gfx908::acc116,480},
     {amdgpu_gfx908::acc117,481},
     {amdgpu_gfx908::acc118,482},
     {amdgpu_gfx908::acc119,483},
     {amdgpu_gfx908::acc120,484},
     {amdgpu_gfx908::acc121,485},
     {amdgpu_gfx908::acc122,486},
     {amdgpu_gfx908::acc123,487},
     {amdgpu_gfx908::acc124,488},
     {amdgpu_gfx908::acc125,489},
     {amdgpu_gfx908::acc126,490},
     {amdgpu_gfx908::acc127,491},
     {amdgpu_gfx908::acc128,492},
     {amdgpu_gfx908::acc129,493},
     {amdgpu_gfx908::acc130,494},
     {amdgpu_gfx908::acc131,495},
     {amdgpu_gfx908::acc132,496},
     {amdgpu_gfx908::acc133,497},
     {amdgpu_gfx908::acc134,498},
     {amdgpu_gfx908::acc135,499},
     {amdgpu_gfx908::acc136,500},
     {amdgpu_gfx908::acc137,501},
     {amdgpu_gfx908::acc138,502},
     {amdgpu_gfx908::acc139,503},
     {amdgpu_gfx908::acc140,504},
     {amdgpu_gfx908::acc141,505},
     {amdgpu_gfx908::acc142,506},
     {amdgpu_gfx908::acc143,507},
     {amdgpu_gfx908::acc144,508},
     {amdgpu_gfx908::acc145,509},
     {amdgpu_gfx908::acc146,510},
     {amdgpu_gfx908::acc147,511},
     {amdgpu_gfx908::acc148,512},
     {amdgpu_gfx908::acc149,513},
     {amdgpu_gfx908::acc150,514},
     {amdgpu_gfx908::acc151,515},
     {amdgpu_gfx908::acc152,516},
     {amdgpu_gfx908::acc153,517},
     {amdgpu_gfx908::acc154,518},
     {amdgpu_gfx908::acc155,519},
     {amdgpu_gfx908::acc156,520},
     {amdgpu_gfx908::acc157,521},
     {amdgpu_gfx908::acc158,522},
     {amdgpu_gfx908::acc159,523},
     {amdgpu_gfx908::acc160,524},
     {amdgpu_gfx908::acc161,525},
     {amdgpu_gfx908::acc162,526},
     {amdgpu_gfx908::acc163,527},
     {amdgpu_gfx908::acc164,528},
     {amdgpu_gfx908::acc165,529},
     {amdgpu_gfx908::acc166,530},
     {amdgpu_gfx908::acc167,531},
     {amdgpu_gfx908::acc168,532},
     {amdgpu_gfx908::acc169,533},
     {amdgpu_gfx908::acc170,534},
     {amdgpu_gfx908::acc171,535},
     {amdgpu_gfx908::acc172,536},
     {amdgpu_gfx908::acc173,537},
     {amdgpu_gfx908::acc174,538},
     {amdgpu_gfx908::acc175,539},
     {amdgpu_gfx908::acc176,540},
     {amdgpu_gfx908::acc177,541},
     {amdgpu_gfx908::acc178,542},
     {amdgpu_gfx908::acc179,543},
     {amdgpu_gfx908::acc180,544},
     {amdgpu_gfx908::acc181,545},
     {amdgpu_gfx908::acc182,546},
     {amdgpu_gfx908::acc183,547},
     {amdgpu_gfx908::acc184,548},
     {amdgpu_gfx908::acc185,549},
     {amdgpu_gfx908::acc186,550},
     {amdgpu_gfx908::acc187,551},
     {amdgpu_gfx908::acc188,552},
     {amdgpu_gfx908::acc189,553},
     {amdgpu_gfx908::acc190,554},
     {amdgpu_gfx908::acc191,555},
     {amdgpu_gfx908::acc192,556},
     {amdgpu_gfx908::acc193,557},
     {amdgpu_gfx908::acc194,558},
     {amdgpu_gfx908::acc195,559},
     {amdgpu_gfx908::acc196,560},
     {amdgpu_gfx908::acc197,561},
     {amdgpu_gfx908::acc198,562},
     {amdgpu_gfx908::acc199,563},
     {amdgpu_gfx908::acc200,564},
     {amdgpu_gfx908::acc201,565},
     {amdgpu_gfx908::acc202,566},
     {amdgpu_gfx908::acc203,567},
     {amdgpu_gfx908::acc204,568},
     {amdgpu_gfx908::acc205,569},
     {amdgpu_gfx908::acc206,570},
     {amdgpu_gfx908::acc207,571},
     {amdgpu_gfx908::acc208,572},
     {amdgpu_gfx908::acc209,573},
     {amdgpu_gfx908::acc210,574},
     {amdgpu_gfx908::acc211,575},
     {amdgpu_gfx908::acc212,576},
     {amdgpu_gfx908::acc213,577},
     {amdgpu_gfx908::acc214,578},
     {amdgpu_gfx908::acc215,579},
     {amdgpu_gfx908::acc216,580},
     {amdgpu_gfx908::acc217,581},
     {amdgpu_gfx908::acc218,582},
     {amdgpu_gfx908::acc219,583},
     {amdgpu_gfx908::acc220,584},
     {amdgpu_gfx908::acc221,585},
     {amdgpu_gfx908::acc222,586},
     {amdgpu_gfx908::acc223,587},
     {amdgpu_gfx908::acc224,588},
     {amdgpu_gfx908::acc225,589},
     {amdgpu_gfx908::acc226,590},
     {amdgpu_gfx908::acc227,591},
     {amdgpu_gfx908::acc228,592},
     {amdgpu_gfx908::acc229,593},
     {amdgpu_gfx908::acc230,594},
     {amdgpu_gfx908::acc231,595},
     {amdgpu_gfx908::acc232,596},
     {amdgpu_gfx908::acc233,597},
     {amdgpu_gfx908::acc234,598},
     {amdgpu_gfx908::acc235,599},
     {amdgpu_gfx908::acc236,600},
     {amdgpu_gfx908::acc237,601},
     {amdgpu_gfx908::acc238,602},
     {amdgpu_gfx908::acc239,603},
     {amdgpu_gfx908::acc240,604},
     {amdgpu_gfx908::acc241,605},
     {amdgpu_gfx908::acc242,606},
     {amdgpu_gfx908::acc243,607},
     {amdgpu_gfx908::acc244,608},
     {amdgpu_gfx908::acc245,609},
     {amdgpu_gfx908::acc246,610},
     {amdgpu_gfx908::acc247,611},
     {amdgpu_gfx908::acc248,612},
     {amdgpu_gfx908::acc249,613},
     {amdgpu_gfx908::acc250,614},
     {amdgpu_gfx908::acc251,615},
     {amdgpu_gfx908::acc252,616},
     {amdgpu_gfx908::acc253,617},
     {amdgpu_gfx908::acc254,618},
     {amdgpu_gfx908::acc255,619}};
    }
    return *mrmap;
}


RegisterMap &machRegIndex_amdgpu_gfx90a() {
   static dyn_tls RegisterMap* mrmap = NULL;
   if (mrmap == NULL) {
      mrmap = new RegisterMap();
      *mrmap = {
     {amdgpu_gfx90a::s0,0},
     {amdgpu_gfx90a::s1,1},
     {amdgpu_gfx90a::s2,2},
     {amdgpu_gfx90a::s3,3},
     {amdgpu_gfx90a::s4,4},
     {amdgpu_gfx90a::s5,5},
     {amdgpu_gfx90a::s6,6},
     {amdgpu_gfx90a::s7,7},
     {amdgpu_gfx90a::s8,8},
     {amdgpu_gfx90a::s9,9},
     {amdgpu_gfx90a::s10,10},
     {amdgpu_gfx90a::s11,11},
     {amdgpu_gfx90a::s12,12},
     {amdgpu_gfx90a::s13,13},
     {amdgpu_gfx90a::s14,14},
     {amdgpu_gfx90a::s15,15},
     {amdgpu_gfx90a::s16,16},
     {amdgpu_gfx90a::s17,17},
     {amdgpu_gfx90a::s18,18},
     {amdgpu_gfx90a::s19,19},
     {amdgpu_gfx90a::s20,20},
     {amdgpu_gfx90a::s21,21},
     {amdgpu_gfx90a::s22,22},
     {amdgpu_gfx90a::s23,23},
     {amdgpu_gfx90a::s24,24},
     {amdgpu_gfx90a::s25,25},
     {amdgpu_gfx90a::s26,26},
     {amdgpu_gfx90a::s27,27},
     {amdgpu_gfx90a::s28,28},
     {amdgpu_gfx90a::s29,29},
     {amdgpu_gfx90a::s30,30},
     {amdgpu_gfx90a::s31,31},
     {amdgpu_gfx90a::s32,32},
     {amdgpu_gfx90a::s33,33},
     {amdgpu_gfx90a::s34,34},
     {amdgpu_gfx90a::s35,35},
     {amdgpu_gfx90a::s36,36},
     {amdgpu_gfx90a::s37,37},
     {amdgpu_gfx90a::s38,38},
     {amdgpu_gfx90a::s39,39},
     {amdgpu_gfx90a::s40,40},
     {amdgpu_gfx90a::s41,41},
     {amdgpu_gfx90a::s42,42},
     {amdgpu_gfx90a::s43,43},
     {amdgpu_gfx90a::s44,44},
     {amdgpu_gfx90a::s45,45},
     {amdgpu_gfx90a::s46,46},
     {amdgpu_gfx90a::s47,47},
     {amdgpu_gfx90a::s48,48},
     {amdgpu_gfx90a::s49,49},
     {amdgpu_gfx90a::s50,50},
     {amdgpu_gfx90a::s51,51},
     {amdgpu_gfx90a::s52,52},
     {amdgpu_gfx90a::s53,53},
     {amdgpu_gfx90a::s54,54},
     {amdgpu_gfx90a::s55,55},
     {amdgpu_gfx90a::s56,56},
     {amdgpu_gfx90a::s57,57},
     {amdgpu_gfx90a::s58,58},
     {amdgpu_gfx90a::s59,59},
     {amdgpu_gfx90a::s60,60},
     {amdgpu_gfx90a::s61,61},
     {amdgpu_gfx90a::s62,62},
     {amdgpu_gfx90a::s63,63},
     {amdgpu_gfx90a::s64,64},
     {amdgpu_gfx90a::s65,65},
     {amdgpu_gfx90a::s66,66},
     {amdgpu_gfx90a::s67,67},
     {amdgpu_gfx90a::s68,68},
     {amdgpu_gfx90a::s69,69},
     {amdgpu_gfx90a::s70,70},
     {amdgpu_gfx90a::s71,71},
     {amdgpu_gfx90a::s72,72},
     {amdgpu_gfx90a::s73,73},
     {amdgpu_gfx90a::s74,74},
     {amdgpu_gfx90a::s75,75},
     {amdgpu_gfx90a::s76,76},
     {amdgpu_gfx90a::s77,77},
     {amdgpu_gfx90a::s78,78},
     {amdgpu_gfx90a::s79,79},
     {amdgpu_gfx90a::s80,80},
     {amdgpu_gfx90a::s81,81},
     {amdgpu_gfx90a::s82,82},
     {amdgpu_gfx90a::s83,83},
     {amdgpu_gfx90a::s84,84},
     {amdgpu_gfx90a::s85,85},
     {amdgpu_gfx90a::s86,86},
     {amdgpu_gfx90a::s87,87},
     {amdgpu_gfx90a::s88,88},
     {amdgpu_gfx90a::s89,89},
     {amdgpu_gfx90a::s90,90},
     {amdgpu_gfx90a::s91,91},
     {amdgpu_gfx90a::s92,92},
     {amdgpu_gfx90a::s93,93},
     {amdgpu_gfx90a::s94,94},
     {amdgpu_gfx90a::s95,95},
     {amdgpu_gfx90a::s96,96},
     {amdgpu_gfx90a::s97,97},
     {amdgpu_gfx90a::s98,98},
     {amdgpu_gfx90a::s99,99},
     {amdgpu_gfx90a::s100,100},
     {amdgpu_gfx90a::s101,101},
     {amdgpu_gfx90a::flat_scratch_lo,102},
     {amdgpu_gfx90a::flat_scratch_hi,103},
     {amdgpu_gfx90a::xnack_mask_lo,104},
     {amdgpu_gfx90a::xnack_mask_hi,105},
     {amdgpu_gfx90a::vcc_lo,106},
     {amdgpu_gfx90a::vcc_hi,107},
     {amdgpu_gfx90a::v0,108},
     {amdgpu_gfx90a::v1,109},
     {amdgpu_gfx90a::v2,110},
     {amdgpu_gfx90a::v3,111},
     {amdgpu_gfx90a::v4,112},
     {amdgpu_gfx90a::v5,113},
     {amdgpu_gfx90a::v6,114},
     {amdgpu_gfx90a::v7,115},
     {amdgpu_gfx90a::v8,116},
     {amdgpu_gfx90a::v9,117},
     {amdgpu_gfx90a::v10,118},
     {amdgpu_gfx90a::v11,119},
     {amdgpu_gfx90a::v12,120},
     {amdgpu_gfx90a::v13,121},
     {amdgpu_gfx90a::v14,122},
     {amdgpu_gfx90a::v15,123},
     {amdgpu_gfx90a::v16,124},
     {amdgpu_gfx90a::v17,125},
     {amdgpu_gfx90a::v18,126},
     {amdgpu_gfx90a::v19,127},
     {amdgpu_gfx90a::v20,128},
     {amdgpu_gfx90a::v21,129},
     {amdgpu_gfx90a::v22,130},
     {amdgpu_gfx90a::v23,131},
     {amdgpu_gfx90a::v24,132},
     {amdgpu_gfx90a::v25,133},
     {amdgpu_gfx90a::v26,134},
     {amdgpu_gfx90a::v27,135},
     {amdgpu_gfx90a::v28,136},
     {amdgpu_gfx90a::v29,137},
     {amdgpu_gfx90a::v30,138},
     {amdgpu_gfx90a::v31,139},
     {amdgpu_gfx90a::v32,140},
     {amdgpu_gfx90a::v33,141},
     {amdgpu_gfx90a::v34,142},
     {amdgpu_gfx90a::v35,143},
     {amdgpu_gfx90a::v36,144},
     {amdgpu_gfx90a::v37,145},
     {amdgpu_gfx90a::v38,146},
     {amdgpu_gfx90a::v39,147},
     {amdgpu_gfx90a::v40,148},
     {amdgpu_gfx90a::v41,149},
     {amdgpu_gfx90a::v42,150},
     {amdgpu_gfx90a::v43,151},
     {amdgpu_gfx90a::v44,152},
     {amdgpu_gfx90a::v45,153},
     {amdgpu_gfx90a::v46,154},
     {amdgpu_gfx90a::v47,155},
     {amdgpu_gfx90a::v48,156},
     {amdgpu_gfx90a::v49,157},
     {amdgpu_gfx90a::v50,158},
     {amdgpu_gfx90a::v51,159},
     {amdgpu_gfx90a::v52,160},
     {amdgpu_gfx90a::v53,161},
     {amdgpu_gfx90a::v54,162},
     {amdgpu_gfx90a::v55,163},
     {amdgpu_gfx90a::v56,164},
     {amdgpu_gfx90a::v57,165},
     {amdgpu_gfx90a::v58,166},
     {amdgpu_gfx90a::v59,167},
     {amdgpu_gfx90a::v60,168},
     {amdgpu_gfx90a::v61,169},
     {amdgpu_gfx90a::v62,170},
     {amdgpu_gfx90a::v63,171},
     {amdgpu_gfx90a::v64,172},
     {amdgpu_gfx90a::v65,173},
     {amdgpu_gfx90a::v66,174},
     {amdgpu_gfx90a::v67,175},
     {amdgpu_gfx90a::v68,176},
     {amdgpu_gfx90a::v69,177},
     {amdgpu_gfx90a::v70,178},
     {amdgpu_gfx90a::v71,179},
     {amdgpu_gfx90a::v72,180},
     {amdgpu_gfx90a::v73,181},
     {amdgpu_gfx90a::v74,182},
     {amdgpu_gfx90a::v75,183},
     {amdgpu_gfx90a::v76,184},
     {amdgpu_gfx90a::v77,185},
     {amdgpu_gfx90a::v78,186},
     {amdgpu_gfx90a::v79,187},
     {amdgpu_gfx90a::v80,188},
     {amdgpu_gfx90a::v81,189},
     {amdgpu_gfx90a::v82,190},
     {amdgpu_gfx90a::v83,191},
     {amdgpu_gfx90a::v84,192},
     {amdgpu_gfx90a::v85,193},
     {amdgpu_gfx90a::v86,194},
     {amdgpu_gfx90a::v87,195},
     {amdgpu_gfx90a::v88,196},
     {amdgpu_gfx90a::v89,197},
     {amdgpu_gfx90a::v90,198},
     {amdgpu_gfx90a::v91,199},
     {amdgpu_gfx90a::v92,200},
     {amdgpu_gfx90a::v93,201},
     {amdgpu_gfx90a::v94,202},
     {amdgpu_gfx90a::v95,203},
     {amdgpu_gfx90a::v96,204},
     {amdgpu_gfx90a::v97,205},
     {amdgpu_gfx90a::v98,206},
     {amdgpu_gfx90a::v99,207},
     {amdgpu_gfx90a::v100,208},
     {amdgpu_gfx90a::v101,209},
     {amdgpu_gfx90a::v102,210},
     {amdgpu_gfx90a::v103,211},
     {amdgpu_gfx90a::v104,212},
     {amdgpu_gfx90a::v105,213},
     {amdgpu_gfx90a::v106,214},
     {amdgpu_gfx90a::v107,215},
     {amdgpu_gfx90a::v108,216},
     {amdgpu_gfx90a::v109,217},
     {amdgpu_gfx90a::v110,218},
     {amdgpu_gfx90a::v111,219},
     {amdgpu_gfx90a::v112,220},
     {amdgpu_gfx90a::v113,221},
     {amdgpu_gfx90a::v114,222},
     {amdgpu_gfx90a::v115,223},
     {amdgpu_gfx90a::v116,224},
     {amdgpu_gfx90a::v117,225},
     {amdgpu_gfx90a::v118,226},
     {amdgpu_gfx90a::v119,227},
     {amdgpu_gfx90a::v120,228},
     {amdgpu_gfx90a::v121,229},
     {amdgpu_gfx90a::v122,230},
     {amdgpu_gfx90a::v123,231},
     {amdgpu_gfx90a::v124,232},
     {amdgpu_gfx90a::v125,233},
     {amdgpu_gfx90a::v126,234},
     {amdgpu_gfx90a::v127,235},
     {amdgpu_gfx90a::v128,236},
     {amdgpu_gfx90a::v129,237},
     {amdgpu_gfx90a::v130,238},
     {amdgpu_gfx90a::v131,239},
     {amdgpu_gfx90a::v132,240},
     {amdgpu_gfx90a::v133,241},
     {amdgpu_gfx90a::v134,242},
     {amdgpu_gfx90a::v135,243},
     {amdgpu_gfx90a::v136,244},
     {amdgpu_gfx90a::v137,245},
     {amdgpu_gfx90a::v138,246},
     {amdgpu_gfx90a::v139,247},
     {amdgpu_gfx90a::v140,248},
     {amdgpu_gfx90a::v141,249},
     {amdgpu_gfx90a::v142,250},
     {amdgpu_gfx90a::v143,251},
     {amdgpu_gfx90a::v144,252},
     {amdgpu_gfx90a::v145,253},
     {amdgpu_gfx90a::v146,254},
     {amdgpu_gfx90a::v147,255},
     {amdgpu_gfx90a::v148,256},
     {amdgpu_gfx90a::v149,257},
     {amdgpu_gfx90a::v150,258},
     {amdgpu_gfx90a::v151,259},
     {amdgpu_gfx90a::v152,260},
     {amdgpu_gfx90a::v153,261},
     {amdgpu_gfx90a::v154,262},
     {amdgpu_gfx90a::v155,263},
     {amdgpu_gfx90a::v156,264},
     {amdgpu_gfx90a::v157,265},
     {amdgpu_gfx90a::v158,266},
     {amdgpu_gfx90a::v159,267},
     {amdgpu_gfx90a::v160,268},
     {amdgpu_gfx90a::v161,269},
     {amdgpu_gfx90a::v162,270},
     {amdgpu_gfx90a::v163,271},
     {amdgpu_gfx90a::v164,272},
     {amdgpu_gfx90a::v165,273},
     {amdgpu_gfx90a::v166,274},
     {amdgpu_gfx90a::v167,275},
     {amdgpu_gfx90a::v168,276},
     {amdgpu_gfx90a::v169,277},
     {amdgpu_gfx90a::v170,278},
     {amdgpu_gfx90a::v171,279},
     {amdgpu_gfx90a::v172,280},
     {amdgpu_gfx90a::v173,281},
     {amdgpu_gfx90a::v174,282},
     {amdgpu_gfx90a::v175,283},
     {amdgpu_gfx90a::v176,284},
     {amdgpu_gfx90a::v177,285},
     {amdgpu_gfx90a::v178,286},
     {amdgpu_gfx90a::v179,287},
     {amdgpu_gfx90a::v180,288},
     {amdgpu_gfx90a::v181,289},
     {amdgpu_gfx90a::v182,290},
     {amdgpu_gfx90a::v183,291},
     {amdgpu_gfx90a::v184,292},
     {amdgpu_gfx90a::v185,293},
     {amdgpu_gfx90a::v186,294},
     {amdgpu_gfx90a::v187,295},
     {amdgpu_gfx90a::v188,296},
     {amdgpu_gfx90a::v189,297},
     {amdgpu_gfx90a::v190,298},
     {amdgpu_gfx90a::v191,299},
     {amdgpu_gfx90a::v192,300},
     {amdgpu_gfx90a::v193,301},
     {amdgpu_gfx90a::v194,302},
     {amdgpu_gfx90a::v195,303},
     {amdgpu_gfx90a::v196,304},
     {amdgpu_gfx90a::v197,305},
     {amdgpu_gfx90a::v198,306},
     {amdgpu_gfx90a::v199,307},
     {amdgpu_gfx90a::v200,308},
     {amdgpu_gfx90a::v201,309},
     {amdgpu_gfx90a::v202,310},
     {amdgpu_gfx90a::v203,311},
     {amdgpu_gfx90a::v204,312},
     {amdgpu_gfx90a::v205,313},
     {amdgpu_gfx90a::v206,314},
     {amdgpu_gfx90a::v207,315},
     {amdgpu_gfx90a::v208,316},
     {amdgpu_gfx90a::v209,317},
     {amdgpu_gfx90a::v210,318},
     {amdgpu_gfx90a::v211,319},
     {amdgpu_gfx90a::v212,320},
     {amdgpu_gfx90a::v213,321},
     {amdgpu_gfx90a::v214,322},
     {amdgpu_gfx90a::v215,323},
     {amdgpu_gfx90a::v216,324},
     {amdgpu_gfx90a::v217,325},
     {amdgpu_gfx90a::v218,326},
     {amdgpu_gfx90a::v219,327},
     {amdgpu_gfx90a::v220,328},
     {amdgpu_gfx90a::v221,329},
     {amdgpu_gfx90a::v222,330},
     {amdgpu_gfx90a::v223,331},
     {amdgpu_gfx90a::v224,332},
     {amdgpu_gfx90a::v225,333},
     {amdgpu_gfx90a::v226,334},
     {amdgpu_gfx90a::v227,335},
     {amdgpu_gfx90a::v228,336},
     {amdgpu_gfx90a::v229,337},
     {amdgpu_gfx90a::v230,338},
     {amdgpu_gfx90a::v231,339},
     {amdgpu_gfx90a::v232,340},
     {amdgpu_gfx90a::v233,341},
     {amdgpu_gfx90a::v234,342},
     {amdgpu_gfx90a::v235,343},
     {amdgpu_gfx90a::v236,344},
     {amdgpu_gfx90a::v237,345},
     {amdgpu_gfx90a::v238,346},
     {amdgpu_gfx90a::v239,347},
     {amdgpu_gfx90a::v240,348},
     {amdgpu_gfx90a::v241,349},
     {amdgpu_gfx90a::v242,350},
     {amdgpu_gfx90a::v243,351},
     {amdgpu_gfx90a::v244,352},
     {amdgpu_gfx90a::v245,353},
     {amdgpu_gfx90a::v246,354},
     {amdgpu_gfx90a::v247,355},
     {amdgpu_gfx90a::v248,356},
     {amdgpu_gfx90a::v249,357},
     {amdgpu_gfx90a::v250,358},
     {amdgpu_gfx90a::v251,359},
     {amdgpu_gfx90a::v252,360},
     {amdgpu_gfx90a::v253,361},
     {amdgpu_gfx90a::v254,362},
     {amdgpu_gfx90a::v255,363},
     {amdgpu_gfx90a::acc0,364},
     {amdgpu_gfx90a::acc1,365},
     {amdgpu_gfx90a::acc2,366},
     {amdgpu_gfx90a::acc3,367},
     {amdgpu_gfx90a::acc4,368},
     {amdgpu_gfx90a::acc5,369},
     {amdgpu_gfx90a::acc6,370},
     {amdgpu_gfx90a::acc7,371},
     {amdgpu_gfx90a::acc8,372},
     {amdgpu_gfx90a::acc9,373},
     {amdgpu_gfx90a::acc10,374},
     {amdgpu_gfx90a::acc11,375},
     {amdgpu_gfx90a::acc12,376},
     {amdgpu_gfx90a::acc13,377},
     {amdgpu_gfx90a::acc14,378},
     {amdgpu_gfx90a::acc15,379},
     {amdgpu_gfx90a::acc16,380},
     {amdgpu_gfx90a::acc17,381},
     {amdgpu_gfx90a::acc18,382},
     {amdgpu_gfx90a::acc19,383},
     {amdgpu_gfx90a::acc20,384},
     {amdgpu_gfx90a::acc21,385},
     {amdgpu_gfx90a::acc22,386},
     {amdgpu_gfx90a::acc23,387},
     {amdgpu_gfx90a::acc24,388},
     {amdgpu_gfx90a::acc25,389},
     {amdgpu_gfx90a::acc26,390},
     {amdgpu_gfx90a::acc27,391},
     {amdgpu_gfx90a::acc28,392},
     {amdgpu_gfx90a::acc29,393},
     {amdgpu_gfx90a::acc30,394},
     {amdgpu_gfx90a::acc31,395},
     {amdgpu_gfx90a::acc32,396},
     {amdgpu_gfx90a::acc33,397},
     {amdgpu_gfx90a::acc34,398},
     {amdgpu_gfx90a::acc35,399},
     {amdgpu_gfx90a::acc36,400},
     {amdgpu_gfx90a::acc37,401},
     {amdgpu_gfx90a::acc38,402},
     {amdgpu_gfx90a::acc39,403},
     {amdgpu_gfx90a::acc40,404},
     {amdgpu_gfx90a::acc41,405},
     {amdgpu_gfx90a::acc42,406},
     {amdgpu_gfx90a::acc43,407},
     {amdgpu_gfx90a::acc44,408},
     {amdgpu_gfx90a::acc45,409},
     {amdgpu_gfx90a::acc46,410},
     {amdgpu_gfx90a::acc47,411},
     {amdgpu_gfx90a::acc48,412},
     {amdgpu_gfx90a::acc49,413},
     {amdgpu_gfx90a::acc50,414},
     {amdgpu_gfx90a::acc51,415},
     {amdgpu_gfx90a::acc52,416},
     {amdgpu_gfx90a::acc53,417},
     {amdgpu_gfx90a::acc54,418},
     {amdgpu_gfx90a::acc55,419},
     {amdgpu_gfx90a::acc56,420},
     {amdgpu_gfx90a::acc57,421},
     {amdgpu_gfx90a::acc58,422},
     {amdgpu_gfx90a::acc59,423},
     {amdgpu_gfx90a::acc60,424},
     {amdgpu_gfx90a::acc61,425},
     {amdgpu_gfx90a::acc62,426},
     {amdgpu_gfx90a::acc63,427},
     {amdgpu_gfx90a::acc64,428},
     {amdgpu_gfx90a::acc65,429},
     {amdgpu_gfx90a::acc66,430},
     {amdgpu_gfx90a::acc67,431},
     {amdgpu_gfx90a::acc68,432},
     {amdgpu_gfx90a::acc69,433},
     {amdgpu_gfx90a::acc70,434},
     {amdgpu_gfx90a::acc71,435},
     {amdgpu_gfx90a::acc72,436},
     {amdgpu_gfx90a::acc73,437},
     {amdgpu_gfx90a::acc74,438},
     {amdgpu_gfx90a::acc75,439},
     {amdgpu_gfx90a::acc76,440},
     {amdgpu_gfx90a::acc77,441},
     {amdgpu_gfx90a::acc78,442},
     {amdgpu_gfx90a::acc79,443},
     {amdgpu_gfx90a::acc80,444},
     {amdgpu_gfx90a::acc81,445},
     {amdgpu_gfx90a::acc82,446},
     {amdgpu_gfx90a::acc83,447},
     {amdgpu_gfx90a::acc84,448},
     {amdgpu_gfx90a::acc85,449},
     {amdgpu_gfx90a::acc86,450},
     {amdgpu_gfx90a::acc87,451},
     {amdgpu_gfx90a::acc88,452},
     {amdgpu_gfx90a::acc89,453},
     {amdgpu_gfx90a::acc90,454},
     {amdgpu_gfx90a::acc91,455},
     {amdgpu_gfx90a::acc92,456},
     {amdgpu_gfx90a::acc93,457},
     {amdgpu_gfx90a::acc94,458},
     {amdgpu_gfx90a::acc95,459},
     {amdgpu_gfx90a::acc96,460},
     {amdgpu_gfx90a::acc97,461},
     {amdgpu_gfx90a::acc98,462},
     {amdgpu_gfx90a::acc99,463},
     {amdgpu_gfx90a::acc100,464},
     {amdgpu_gfx90a::acc101,465},
     {amdgpu_gfx90a::acc102,466},
     {amdgpu_gfx90a::acc103,467},
     {amdgpu_gfx90a::acc104,468},
     {amdgpu_gfx90a::acc105,469},
     {amdgpu_gfx90a::acc106,470},
     {amdgpu_gfx90a::acc107,471},
     {amdgpu_gfx90a::acc108,472},
     {amdgpu_gfx90a::acc109,473},
     {amdgpu_gfx90a::acc110,474},
     {amdgpu_gfx90a::acc111,475},
     {amdgpu_gfx90a::acc112,476},
     {amdgpu_gfx90a::acc113,477},
     {amdgpu_gfx90a::acc114,478},
     {amdgpu_gfx90a::acc115,479},
     {amdgpu_gfx90a::acc116,480},
     {amdgpu_gfx90a::acc117,481},
     {amdgpu_gfx90a::acc118,482},
     {amdgpu_gfx90a::acc119,483},
     {amdgpu_gfx90a::acc120,484},
     {amdgpu_gfx90a::acc121,485},
     {amdgpu_gfx90a::acc122,486},
     {amdgpu_gfx90a::acc123,487},
     {amdgpu_gfx90a::acc124,488},
     {amdgpu_gfx90a::acc125,489},
     {amdgpu_gfx90a::acc126,490},
     {amdgpu_gfx90a::acc127,491},
     {amdgpu_gfx90a::acc128,492},
     {amdgpu_gfx90a::acc129,493},
     {amdgpu_gfx90a::acc130,494},
     {amdgpu_gfx90a::acc131,495},
     {amdgpu_gfx90a::acc132,496},
     {amdgpu_gfx90a::acc133,497},
     {amdgpu_gfx90a::acc134,498},
     {amdgpu_gfx90a::acc135,499},
     {amdgpu_gfx90a::acc136,500},
     {amdgpu_gfx90a::acc137,501},
     {amdgpu_gfx90a::acc138,502},
     {amdgpu_gfx90a::acc139,503},
     {amdgpu_gfx90a::acc140,504},
     {amdgpu_gfx90a::acc141,505},
     {amdgpu_gfx90a::acc142,506},
     {amdgpu_gfx90a::acc143,507},
     {amdgpu_gfx90a::acc144,508},
     {amdgpu_gfx90a::acc145,509},
     {amdgpu_gfx90a::acc146,510},
     {amdgpu_gfx90a::acc147,511},
     {amdgpu_gfx90a::acc148,512},
     {amdgpu_gfx90a::acc149,513},
     {amdgpu_gfx90a::acc150,514},
     {amdgpu_gfx90a::acc151,515},
     {amdgpu_gfx90a::acc152,516},
     {amdgpu_gfx90a::acc153,517},
     {amdgpu_gfx90a::acc154,518},
     {amdgpu_gfx90a::acc155,519},
     {amdgpu_gfx90a::acc156,520},
     {amdgpu_gfx90a::acc157,521},
     {amdgpu_gfx90a::acc158,522},
     {amdgpu_gfx90a::acc159,523},
     {amdgpu_gfx90a::acc160,524},
     {amdgpu_gfx90a::acc161,525},
     {amdgpu_gfx90a::acc162,526},
     {amdgpu_gfx90a::acc163,527},
     {amdgpu_gfx90a::acc164,528},
     {amdgpu_gfx90a::acc165,529},
     {amdgpu_gfx90a::acc166,530},
     {amdgpu_gfx90a::acc167,531},
     {amdgpu_gfx90a::acc168,532},
     {amdgpu_gfx90a::acc169,533},
     {amdgpu_gfx90a::acc170,534},
     {amdgpu_gfx90a::acc171,535},
     {amdgpu_gfx90a::acc172,536},
     {amdgpu_gfx90a::acc173,537},
     {amdgpu_gfx90a::acc174,538},
     {amdgpu_gfx90a::acc175,539},
     {amdgpu_gfx90a::acc176,540},
     {amdgpu_gfx90a::acc177,541},
     {amdgpu_gfx90a::acc178,542},
     {amdgpu_gfx90a::acc179,543},
     {amdgpu_gfx90a::acc180,544},
     {amdgpu_gfx90a::acc181,545},
     {amdgpu_gfx90a::acc182,546},
     {amdgpu_gfx90a::acc183,547},
     {amdgpu_gfx90a::acc184,548},
     {amdgpu_gfx90a::acc185,549},
     {amdgpu_gfx90a::acc186,550},
     {amdgpu_gfx90a::acc187,551},
     {amdgpu_gfx90a::acc188,552},
     {amdgpu_gfx90a::acc189,553},
     {amdgpu_gfx90a::acc190,554},
     {amdgpu_gfx90a::acc191,555},
     {amdgpu_gfx90a::acc192,556},
     {amdgpu_gfx90a::acc193,557},
     {amdgpu_gfx90a::acc194,558},
     {amdgpu_gfx90a::acc195,559},
     {amdgpu_gfx90a::acc196,560},
     {amdgpu_gfx90a::acc197,561},
     {amdgpu_gfx90a::acc198,562},
     {amdgpu_gfx90a::acc199,563},
     {amdgpu_gfx90a::acc200,564},
     {amdgpu_gfx90a::acc201,565},
     {amdgpu_gfx90a::acc202,566},
     {amdgpu_gfx90a::acc203,567},
     {amdgpu_gfx90a::acc204,568},
     {amdgpu_gfx90a::acc205,569},
     {amdgpu_gfx90a::acc206,570},
     {amdgpu_gfx90a::acc207,571},
     {amdgpu_gfx90a::acc208,572},
     {amdgpu_gfx90a::acc209,573},
     {amdgpu_gfx90a::acc210,574},
     {amdgpu_gfx90a::acc211,575},
     {amdgpu_gfx90a::acc212,576},
     {amdgpu_gfx90a::acc213,577},
     {amdgpu_gfx90a::acc214,578},
     {amdgpu_gfx90a::acc215,579},
     {amdgpu_gfx90a::acc216,580},
     {amdgpu_gfx90a::acc217,581},
     {amdgpu_gfx90a::acc218,582},
     {amdgpu_gfx90a::acc219,583},
     {amdgpu_gfx90a::acc220,584},
     {amdgpu_gfx90a::acc221,585},
     {amdgpu_gfx90a::acc222,586},
     {amdgpu_gfx90a::acc223,587},
     {amdgpu_gfx90a::acc224,588},
     {amdgpu_gfx90a::acc225,589},
     {amdgpu_gfx90a::acc226,590},
     {amdgpu_gfx90a::acc227,591},
     {amdgpu_gfx90a::acc228,592},
     {amdgpu_gfx90a::acc229,593},
     {amdgpu_gfx90a::acc230,594},
     {amdgpu_gfx90a::acc231,595},
     {amdgpu_gfx90a::acc232,596},
     {amdgpu_gfx90a::acc233,597},
     {amdgpu_gfx90a::acc234,598},
     {amdgpu_gfx90a::acc235,599},
     {amdgpu_gfx90a::acc236,600},
     {amdgpu_gfx90a::acc237,601},
     {amdgpu_gfx90a::acc238,602},
     {amdgpu_gfx90a::acc239,603},
     {amdgpu_gfx90a::acc240,604},
     {amdgpu_gfx90a::acc241,605},
     {amdgpu_gfx90a::acc242,606},
     {amdgpu_gfx90a::acc243,607},
     {amdgpu_gfx90a::acc244,608},
     {amdgpu_gfx90a::acc245,609},
     {amdgpu_gfx90a::acc246,610},
     {amdgpu_gfx90a::acc247,611},
     {amdgpu_gfx90a::acc248,612},
     {amdgpu_gfx90a::acc249,613},
     {amdgpu_gfx90a::acc250,614},
     {amdgpu_gfx90a::acc251,615},
     {amdgpu_gfx90a::acc252,616},
     {amdgpu_gfx90a::acc253,617},
     {amdgpu_gfx90a::acc254,618},
     {amdgpu_gfx90a::acc255,619}};
    }
    return *mrmap;
}

RegisterMap &machRegIndex_amdgpu_gfx940() {
   static dyn_tls RegisterMap* mrmap = NULL;
   if (mrmap == NULL) {
      mrmap = new RegisterMap();
      *mrmap = {
     {amdgpu_gfx940::s0,0},
     {amdgpu_gfx940::s1,1},
     {amdgpu_gfx940::s2,2},
     {amdgpu_gfx940::s3,3},
     {amdgpu_gfx940::s4,4},
     {amdgpu_gfx940::s5,5},
     {amdgpu_gfx940::s6,6},
     {amdgpu_gfx940::s7,7},
     {amdgpu_gfx940::s8,8},
     {amdgpu_gfx940::s9,9},
     {amdgpu_gfx940::s10,10},
     {amdgpu_gfx940::s11,11},
     {amdgpu_gfx940::s12,12},
     {amdgpu_gfx940::s13,13},
     {amdgpu_gfx940::s14,14},
     {amdgpu_gfx940::s15,15},
     {amdgpu_gfx940::s16,16},
     {amdgpu_gfx940::s17,17},
     {amdgpu_gfx940::s18,18},
     {amdgpu_gfx940::s19,19},
     {amdgpu_gfx940::s20,20},
     {amdgpu_gfx940::s21,21},
     {amdgpu_gfx940::s22,22},
     {amdgpu_gfx940::s23,23},
     {amdgpu_gfx940::s24,24},
     {amdgpu_gfx940::s25,25},
     {amdgpu_gfx940::s26,26},
     {amdgpu_gfx940::s27,27},
     {amdgpu_gfx940::s28,28},
     {amdgpu_gfx940::s29,29},
     {amdgpu_gfx940::s30,30},
     {amdgpu_gfx940::s31,31},
     {amdgpu_gfx940::s32,32},
     {amdgpu_gfx940::s33,33},
     {amdgpu_gfx940::s34,34},
     {amdgpu_gfx940::s35,35},
     {amdgpu_gfx940::s36,36},
     {amdgpu_gfx940::s37,37},
     {amdgpu_gfx940::s38,38},
     {amdgpu_gfx940::s39,39},
     {amdgpu_gfx940::s40,40},
     {amdgpu_gfx940::s41,41},
     {amdgpu_gfx940::s42,42},
     {amdgpu_gfx940::s43,43},
     {amdgpu_gfx940::s44,44},
     {amdgpu_gfx940::s45,45},
     {amdgpu_gfx940::s46,46},
     {amdgpu_gfx940::s47,47},
     {amdgpu_gfx940::s48,48},
     {amdgpu_gfx940::s49,49},
     {amdgpu_gfx940::s50,50},
     {amdgpu_gfx940::s51,51},
     {amdgpu_gfx940::s52,52},
     {amdgpu_gfx940::s53,53},
     {amdgpu_gfx940::s54,54},
     {amdgpu_gfx940::s55,55},
     {amdgpu_gfx940::s56,56},
     {amdgpu_gfx940::s57,57},
     {amdgpu_gfx940::s58,58},
     {amdgpu_gfx940::s59,59},
     {amdgpu_gfx940::s60,60},
     {amdgpu_gfx940::s61,61},
     {amdgpu_gfx940::s62,62},
     {amdgpu_gfx940::s63,63},
     {amdgpu_gfx940::s64,64},
     {amdgpu_gfx940::s65,65},
     {amdgpu_gfx940::s66,66},
     {amdgpu_gfx940::s67,67},
     {amdgpu_gfx940::s68,68},
     {amdgpu_gfx940::s69,69},
     {amdgpu_gfx940::s70,70},
     {amdgpu_gfx940::s71,71},
     {amdgpu_gfx940::s72,72},
     {amdgpu_gfx940::s73,73},
     {amdgpu_gfx940::s74,74},
     {amdgpu_gfx940::s75,75},
     {amdgpu_gfx940::s76,76},
     {amdgpu_gfx940::s77,77},
     {amdgpu_gfx940::s78,78},
     {amdgpu_gfx940::s79,79},
     {amdgpu_gfx940::s80,80},
     {amdgpu_gfx940::s81,81},
     {amdgpu_gfx940::s82,82},
     {amdgpu_gfx940::s83,83},
     {amdgpu_gfx940::s84,84},
     {amdgpu_gfx940::s85,85},
     {amdgpu_gfx940::s86,86},
     {amdgpu_gfx940::s87,87},
     {amdgpu_gfx940::s88,88},
     {amdgpu_gfx940::s89,89},
     {amdgpu_gfx940::s90,90},
     {amdgpu_gfx940::s91,91},
     {amdgpu_gfx940::s92,92},
     {amdgpu_gfx940::s93,93},
     {amdgpu_gfx940::s94,94},
     {amdgpu_gfx940::s95,95},
     {amdgpu_gfx940::s96,96},
     {amdgpu_gfx940::s97,97},
     {amdgpu_gfx940::s98,98},
     {amdgpu_gfx940::s99,99},
     {amdgpu_gfx940::s100,100},
     {amdgpu_gfx940::s101,101},
     {amdgpu_gfx940::flat_scratch_lo,102},
     {amdgpu_gfx940::flat_scratch_hi,103},
     {amdgpu_gfx940::xnack_mask_lo,104},
     {amdgpu_gfx940::xnack_mask_hi,105},
     {amdgpu_gfx940::vcc_lo,106},
     {amdgpu_gfx940::vcc_hi,107},
     {amdgpu_gfx940::v0,108},
     {amdgpu_gfx940::v1,109},
     {amdgpu_gfx940::v2,110},
     {amdgpu_gfx940::v3,111},
     {amdgpu_gfx940::v4,112},
     {amdgpu_gfx940::v5,113},
     {amdgpu_gfx940::v6,114},
     {amdgpu_gfx940::v7,115},
     {amdgpu_gfx940::v8,116},
     {amdgpu_gfx940::v9,117},
     {amdgpu_gfx940::v10,118},
     {amdgpu_gfx940::v11,119},
     {amdgpu_gfx940::v12,120},
     {amdgpu_gfx940::v13,121},
     {amdgpu_gfx940::v14,122},
     {amdgpu_gfx940::v15,123},
     {amdgpu_gfx940::v16,124},
     {amdgpu_gfx940::v17,125},
     {amdgpu_gfx940::v18,126},
     {amdgpu_gfx940::v19,127},
     {amdgpu_gfx940::v20,128},
     {amdgpu_gfx940::v21,129},
     {amdgpu_gfx940::v22,130},
     {amdgpu_gfx940::v23,131},
     {amdgpu_gfx940::v24,132},
     {amdgpu_gfx940::v25,133},
     {amdgpu_gfx940::v26,134},
     {amdgpu_gfx940::v27,135},
     {amdgpu_gfx940::v28,136},
     {amdgpu_gfx940::v29,137},
     {amdgpu_gfx940::v30,138},
     {amdgpu_gfx940::v31,139},
     {amdgpu_gfx940::v32,140},
     {amdgpu_gfx940::v33,141},
     {amdgpu_gfx940::v34,142},
     {amdgpu_gfx940::v35,143},
     {amdgpu_gfx940::v36,144},
     {amdgpu_gfx940::v37,145},
     {amdgpu_gfx940::v38,146},
     {amdgpu_gfx940::v39,147},
     {amdgpu_gfx940::v40,148},
     {amdgpu_gfx940::v41,149},
     {amdgpu_gfx940::v42,150},
     {amdgpu_gfx940::v43,151},
     {amdgpu_gfx940::v44,152},
     {amdgpu_gfx940::v45,153},
     {amdgpu_gfx940::v46,154},
     {amdgpu_gfx940::v47,155},
     {amdgpu_gfx940::v48,156},
     {amdgpu_gfx940::v49,157},
     {amdgpu_gfx940::v50,158},
     {amdgpu_gfx940::v51,159},
     {amdgpu_gfx940::v52,160},
     {amdgpu_gfx940::v53,161},
     {amdgpu_gfx940::v54,162},
     {amdgpu_gfx940::v55,163},
     {amdgpu_gfx940::v56,164},
     {amdgpu_gfx940::v57,165},
     {amdgpu_gfx940::v58,166},
     {amdgpu_gfx940::v59,167},
     {amdgpu_gfx940::v60,168},
     {amdgpu_gfx940::v61,169},
     {amdgpu_gfx940::v62,170},
     {amdgpu_gfx940::v63,171},
     {amdgpu_gfx940::v64,172},
     {amdgpu_gfx940::v65,173},
     {amdgpu_gfx940::v66,174},
     {amdgpu_gfx940::v67,175},
     {amdgpu_gfx940::v68,176},
     {amdgpu_gfx940::v69,177},
     {amdgpu_gfx940::v70,178},
     {amdgpu_gfx940::v71,179},
     {amdgpu_gfx940::v72,180},
     {amdgpu_gfx940::v73,181},
     {amdgpu_gfx940::v74,182},
     {amdgpu_gfx940::v75,183},
     {amdgpu_gfx940::v76,184},
     {amdgpu_gfx940::v77,185},
     {amdgpu_gfx940::v78,186},
     {amdgpu_gfx940::v79,187},
     {amdgpu_gfx940::v80,188},
     {amdgpu_gfx940::v81,189},
     {amdgpu_gfx940::v82,190},
     {amdgpu_gfx940::v83,191},
     {amdgpu_gfx940::v84,192},
     {amdgpu_gfx940::v85,193},
     {amdgpu_gfx940::v86,194},
     {amdgpu_gfx940::v87,195},
     {amdgpu_gfx940::v88,196},
     {amdgpu_gfx940::v89,197},
     {amdgpu_gfx940::v90,198},
     {amdgpu_gfx940::v91,199},
     {amdgpu_gfx940::v92,200},
     {amdgpu_gfx940::v93,201},
     {amdgpu_gfx940::v94,202},
     {amdgpu_gfx940::v95,203},
     {amdgpu_gfx940::v96,204},
     {amdgpu_gfx940::v97,205},
     {amdgpu_gfx940::v98,206},
     {amdgpu_gfx940::v99,207},
     {amdgpu_gfx940::v100,208},
     {amdgpu_gfx940::v101,209},
     {amdgpu_gfx940::v102,210},
     {amdgpu_gfx940::v103,211},
     {amdgpu_gfx940::v104,212},
     {amdgpu_gfx940::v105,213},
     {amdgpu_gfx940::v106,214},
     {amdgpu_gfx940::v107,215},
     {amdgpu_gfx940::v108,216},
     {amdgpu_gfx940::v109,217},
     {amdgpu_gfx940::v110,218},
     {amdgpu_gfx940::v111,219},
     {amdgpu_gfx940::v112,220},
     {amdgpu_gfx940::v113,221},
     {amdgpu_gfx940::v114,222},
     {amdgpu_gfx940::v115,223},
     {amdgpu_gfx940::v116,224},
     {amdgpu_gfx940::v117,225},
     {amdgpu_gfx940::v118,226},
     {amdgpu_gfx940::v119,227},
     {amdgpu_gfx940::v120,228},
     {amdgpu_gfx940::v121,229},
     {amdgpu_gfx940::v122,230},
     {amdgpu_gfx940::v123,231},
     {amdgpu_gfx940::v124,232},
     {amdgpu_gfx940::v125,233},
     {amdgpu_gfx940::v126,234},
     {amdgpu_gfx940::v127,235},
     {amdgpu_gfx940::v128,236},
     {amdgpu_gfx940::v129,237},
     {amdgpu_gfx940::v130,238},
     {amdgpu_gfx940::v131,239},
     {amdgpu_gfx940::v132,240},
     {amdgpu_gfx940::v133,241},
     {amdgpu_gfx940::v134,242},
     {amdgpu_gfx940::v135,243},
     {amdgpu_gfx940::v136,244},
     {amdgpu_gfx940::v137,245},
     {amdgpu_gfx940::v138,246},
     {amdgpu_gfx940::v139,247},
     {amdgpu_gfx940::v140,248},
     {amdgpu_gfx940::v141,249},
     {amdgpu_gfx940::v142,250},
     {amdgpu_gfx940::v143,251},
     {amdgpu_gfx940::v144,252},
     {amdgpu_gfx940::v145,253},
     {amdgpu_gfx940::v146,254},
     {amdgpu_gfx940::v147,255},
     {amdgpu_gfx940::v148,256},
     {amdgpu_gfx940::v149,257},
     {amdgpu_gfx940::v150,258},
     {amdgpu_gfx940::v151,259},
     {amdgpu_gfx940::v152,260},
     {amdgpu_gfx940::v153,261},
     {amdgpu_gfx940::v154,262},
     {amdgpu_gfx940::v155,263},
     {amdgpu_gfx940::v156,264},
     {amdgpu_gfx940::v157,265},
     {amdgpu_gfx940::v158,266},
     {amdgpu_gfx940::v159,267},
     {amdgpu_gfx940::v160,268},
     {amdgpu_gfx940::v161,269},
     {amdgpu_gfx940::v162,270},
     {amdgpu_gfx940::v163,271},
     {amdgpu_gfx940::v164,272},
     {amdgpu_gfx940::v165,273},
     {amdgpu_gfx940::v166,274},
     {amdgpu_gfx940::v167,275},
     {amdgpu_gfx940::v168,276},
     {amdgpu_gfx940::v169,277},
     {amdgpu_gfx940::v170,278},
     {amdgpu_gfx940::v171,279},
     {amdgpu_gfx940::v172,280},
     {amdgpu_gfx940::v173,281},
     {amdgpu_gfx940::v174,282},
     {amdgpu_gfx940::v175,283},
     {amdgpu_gfx940::v176,284},
     {amdgpu_gfx940::v177,285},
     {amdgpu_gfx940::v178,286},
     {amdgpu_gfx940::v179,287},
     {amdgpu_gfx940::v180,288},
     {amdgpu_gfx940::v181,289},
     {amdgpu_gfx940::v182,290},
     {amdgpu_gfx940::v183,291},
     {amdgpu_gfx940::v184,292},
     {amdgpu_gfx940::v185,293},
     {amdgpu_gfx940::v186,294},
     {amdgpu_gfx940::v187,295},
     {amdgpu_gfx940::v188,296},
     {amdgpu_gfx940::v189,297},
     {amdgpu_gfx940::v190,298},
     {amdgpu_gfx940::v191,299},
     {amdgpu_gfx940::v192,300},
     {amdgpu_gfx940::v193,301},
     {amdgpu_gfx940::v194,302},
     {amdgpu_gfx940::v195,303},
     {amdgpu_gfx940::v196,304},
     {amdgpu_gfx940::v197,305},
     {amdgpu_gfx940::v198,306},
     {amdgpu_gfx940::v199,307},
     {amdgpu_gfx940::v200,308},
     {amdgpu_gfx940::v201,309},
     {amdgpu_gfx940::v202,310},
     {amdgpu_gfx940::v203,311},
     {amdgpu_gfx940::v204,312},
     {amdgpu_gfx940::v205,313},
     {amdgpu_gfx940::v206,314},
     {amdgpu_gfx940::v207,315},
     {amdgpu_gfx940::v208,316},
     {amdgpu_gfx940::v209,317},
     {amdgpu_gfx940::v210,318},
     {amdgpu_gfx940::v211,319},
     {amdgpu_gfx940::v212,320},
     {amdgpu_gfx940::v213,321},
     {amdgpu_gfx940::v214,322},
     {amdgpu_gfx940::v215,323},
     {amdgpu_gfx940::v216,324},
     {amdgpu_gfx940::v217,325},
     {amdgpu_gfx940::v218,326},
     {amdgpu_gfx940::v219,327},
     {amdgpu_gfx940::v220,328},
     {amdgpu_gfx940::v221,329},
     {amdgpu_gfx940::v222,330},
     {amdgpu_gfx940::v223,331},
     {amdgpu_gfx940::v224,332},
     {amdgpu_gfx940::v225,333},
     {amdgpu_gfx940::v226,334},
     {amdgpu_gfx940::v227,335},
     {amdgpu_gfx940::v228,336},
     {amdgpu_gfx940::v229,337},
     {amdgpu_gfx940::v230,338},
     {amdgpu_gfx940::v231,339},
     {amdgpu_gfx940::v232,340},
     {amdgpu_gfx940::v233,341},
     {amdgpu_gfx940::v234,342},
     {amdgpu_gfx940::v235,343},
     {amdgpu_gfx940::v236,344},
     {amdgpu_gfx940::v237,345},
     {amdgpu_gfx940::v238,346},
     {amdgpu_gfx940::v239,347},
     {amdgpu_gfx940::v240,348},
     {amdgpu_gfx940::v241,349},
     {amdgpu_gfx940::v242,350},
     {amdgpu_gfx940::v243,351},
     {amdgpu_gfx940::v244,352},
     {amdgpu_gfx940::v245,353},
     {amdgpu_gfx940::v246,354},
     {amdgpu_gfx940::v247,355},
     {amdgpu_gfx940::v248,356},
     {amdgpu_gfx940::v249,357},
     {amdgpu_gfx940::v250,358},
     {amdgpu_gfx940::v251,359},
     {amdgpu_gfx940::v252,360},
     {amdgpu_gfx940::v253,361},
     {amdgpu_gfx940::v254,362},
     {amdgpu_gfx940::v255,363},
     {amdgpu_gfx940::acc0,364},
     {amdgpu_gfx940::acc1,365},
     {amdgpu_gfx940::acc2,366},
     {amdgpu_gfx940::acc3,367},
     {amdgpu_gfx940::acc4,368},
     {amdgpu_gfx940::acc5,369},
     {amdgpu_gfx940::acc6,370},
     {amdgpu_gfx940::acc7,371},
     {amdgpu_gfx940::acc8,372},
     {amdgpu_gfx940::acc9,373},
     {amdgpu_gfx940::acc10,374},
     {amdgpu_gfx940::acc11,375},
     {amdgpu_gfx940::acc12,376},
     {amdgpu_gfx940::acc13,377},
     {amdgpu_gfx940::acc14,378},
     {amdgpu_gfx940::acc15,379},
     {amdgpu_gfx940::acc16,380},
     {amdgpu_gfx940::acc17,381},
     {amdgpu_gfx940::acc18,382},
     {amdgpu_gfx940::acc19,383},
     {amdgpu_gfx940::acc20,384},
     {amdgpu_gfx940::acc21,385},
     {amdgpu_gfx940::acc22,386},
     {amdgpu_gfx940::acc23,387},
     {amdgpu_gfx940::acc24,388},
     {amdgpu_gfx940::acc25,389},
     {amdgpu_gfx940::acc26,390},
     {amdgpu_gfx940::acc27,391},
     {amdgpu_gfx940::acc28,392},
     {amdgpu_gfx940::acc29,393},
     {amdgpu_gfx940::acc30,394},
     {amdgpu_gfx940::acc31,395},
     {amdgpu_gfx940::acc32,396},
     {amdgpu_gfx940::acc33,397},
     {amdgpu_gfx940::acc34,398},
     {amdgpu_gfx940::acc35,399},
     {amdgpu_gfx940::acc36,400},
     {amdgpu_gfx940::acc37,401},
     {amdgpu_gfx940::acc38,402},
     {amdgpu_gfx940::acc39,403},
     {amdgpu_gfx940::acc40,404},
     {amdgpu_gfx940::acc41,405},
     {amdgpu_gfx940::acc42,406},
     {amdgpu_gfx940::acc43,407},
     {amdgpu_gfx940::acc44,408},
     {amdgpu_gfx940::acc45,409},
     {amdgpu_gfx940::acc46,410},
     {amdgpu_gfx940::acc47,411},
     {amdgpu_gfx940::acc48,412},
     {amdgpu_gfx940::acc49,413},
     {amdgpu_gfx940::acc50,414},
     {amdgpu_gfx940::acc51,415},
     {amdgpu_gfx940::acc52,416},
     {amdgpu_gfx940::acc53,417},
     {amdgpu_gfx940::acc54,418},
     {amdgpu_gfx940::acc55,419},
     {amdgpu_gfx940::acc56,420},
     {amdgpu_gfx940::acc57,421},
     {amdgpu_gfx940::acc58,422},
     {amdgpu_gfx940::acc59,423},
     {amdgpu_gfx940::acc60,424},
     {amdgpu_gfx940::acc61,425},
     {amdgpu_gfx940::acc62,426},
     {amdgpu_gfx940::acc63,427},
     {amdgpu_gfx940::acc64,428},
     {amdgpu_gfx940::acc65,429},
     {amdgpu_gfx940::acc66,430},
     {amdgpu_gfx940::acc67,431},
     {amdgpu_gfx940::acc68,432},
     {amdgpu_gfx940::acc69,433},
     {amdgpu_gfx940::acc70,434},
     {amdgpu_gfx940::acc71,435},
     {amdgpu_gfx940::acc72,436},
     {amdgpu_gfx940::acc73,437},
     {amdgpu_gfx940::acc74,438},
     {amdgpu_gfx940::acc75,439},
     {amdgpu_gfx940::acc76,440},
     {amdgpu_gfx940::acc77,441},
     {amdgpu_gfx940::acc78,442},
     {amdgpu_gfx940::acc79,443},
     {amdgpu_gfx940::acc80,444},
     {amdgpu_gfx940::acc81,445},
     {amdgpu_gfx940::acc82,446},
     {amdgpu_gfx940::acc83,447},
     {amdgpu_gfx940::acc84,448},
     {amdgpu_gfx940::acc85,449},
     {amdgpu_gfx940::acc86,450},
     {amdgpu_gfx940::acc87,451},
     {amdgpu_gfx940::acc88,452},
     {amdgpu_gfx940::acc89,453},
     {amdgpu_gfx940::acc90,454},
     {amdgpu_gfx940::acc91,455},
     {amdgpu_gfx940::acc92,456},
     {amdgpu_gfx940::acc93,457},
     {amdgpu_gfx940::acc94,458},
     {amdgpu_gfx940::acc95,459},
     {amdgpu_gfx940::acc96,460},
     {amdgpu_gfx940::acc97,461},
     {amdgpu_gfx940::acc98,462},
     {amdgpu_gfx940::acc99,463},
     {amdgpu_gfx940::acc100,464},
     {amdgpu_gfx940::acc101,465},
     {amdgpu_gfx940::acc102,466},
     {amdgpu_gfx940::acc103,467},
     {amdgpu_gfx940::acc104,468},
     {amdgpu_gfx940::acc105,469},
     {amdgpu_gfx940::acc106,470},
     {amdgpu_gfx940::acc107,471},
     {amdgpu_gfx940::acc108,472},
     {amdgpu_gfx940::acc109,473},
     {amdgpu_gfx940::acc110,474},
     {amdgpu_gfx940::acc111,475},
     {amdgpu_gfx940::acc112,476},
     {amdgpu_gfx940::acc113,477},
     {amdgpu_gfx940::acc114,478},
     {amdgpu_gfx940::acc115,479},
     {amdgpu_gfx940::acc116,480},
     {amdgpu_gfx940::acc117,481},
     {amdgpu_gfx940::acc118,482},
     {amdgpu_gfx940::acc119,483},
     {amdgpu_gfx940::acc120,484},
     {amdgpu_gfx940::acc121,485},
     {amdgpu_gfx940::acc122,486},
     {amdgpu_gfx940::acc123,487},
     {amdgpu_gfx940::acc124,488},
     {amdgpu_gfx940::acc125,489},
     {amdgpu_gfx940::acc126,490},
     {amdgpu_gfx940::acc127,491},
     {amdgpu_gfx940::acc128,492},
     {amdgpu_gfx940::acc129,493},
     {amdgpu_gfx940::acc130,494},
     {amdgpu_gfx940::acc131,495},
     {amdgpu_gfx940::acc132,496},
     {amdgpu_gfx940::acc133,497},
     {amdgpu_gfx940::acc134,498},
     {amdgpu_gfx940::acc135,499},
     {amdgpu_gfx940::acc136,500},
     {amdgpu_gfx940::acc137,501},
     {amdgpu_gfx940::acc138,502},
     {amdgpu_gfx940::acc139,503},
     {amdgpu_gfx940::acc140,504},
     {amdgpu_gfx940::acc141,505},
     {amdgpu_gfx940::acc142,506},
     {amdgpu_gfx940::acc143,507},
     {amdgpu_gfx940::acc144,508},
     {amdgpu_gfx940::acc145,509},
     {amdgpu_gfx940::acc146,510},
     {amdgpu_gfx940::acc147,511},
     {amdgpu_gfx940::acc148,512},
     {amdgpu_gfx940::acc149,513},
     {amdgpu_gfx940::acc150,514},
     {amdgpu_gfx940::acc151,515},
     {amdgpu_gfx940::acc152,516},
     {amdgpu_gfx940::acc153,517},
     {amdgpu_gfx940::acc154,518},
     {amdgpu_gfx940::acc155,519},
     {amdgpu_gfx940::acc156,520},
     {amdgpu_gfx940::acc157,521},
     {amdgpu_gfx940::acc158,522},
     {amdgpu_gfx940::acc159,523},
     {amdgpu_gfx940::acc160,524},
     {amdgpu_gfx940::acc161,525},
     {amdgpu_gfx940::acc162,526},
     {amdgpu_gfx940::acc163,527},
     {amdgpu_gfx940::acc164,528},
     {amdgpu_gfx940::acc165,529},
     {amdgpu_gfx940::acc166,530},
     {amdgpu_gfx940::acc167,531},
     {amdgpu_gfx940::acc168,532},
     {amdgpu_gfx940::acc169,533},
     {amdgpu_gfx940::acc170,534},
     {amdgpu_gfx940::acc171,535},
     {amdgpu_gfx940::acc172,536},
     {amdgpu_gfx940::acc173,537},
     {amdgpu_gfx940::acc174,538},
     {amdgpu_gfx940::acc175,539},
     {amdgpu_gfx940::acc176,540},
     {amdgpu_gfx940::acc177,541},
     {amdgpu_gfx940::acc178,542},
     {amdgpu_gfx940::acc179,543},
     {amdgpu_gfx940::acc180,544},
     {amdgpu_gfx940::acc181,545},
     {amdgpu_gfx940::acc182,546},
     {amdgpu_gfx940::acc183,547},
     {amdgpu_gfx940::acc184,548},
     {amdgpu_gfx940::acc185,549},
     {amdgpu_gfx940::acc186,550},
     {amdgpu_gfx940::acc187,551},
     {amdgpu_gfx940::acc188,552},
     {amdgpu_gfx940::acc189,553},
     {amdgpu_gfx940::acc190,554},
     {amdgpu_gfx940::acc191,555},
     {amdgpu_gfx940::acc192,556},
     {amdgpu_gfx940::acc193,557},
     {amdgpu_gfx940::acc194,558},
     {amdgpu_gfx940::acc195,559},
     {amdgpu_gfx940::acc196,560},
     {amdgpu_gfx940::acc197,561},
     {amdgpu_gfx940::acc198,562},
     {amdgpu_gfx940::acc199,563},
     {amdgpu_gfx940::acc200,564},
     {amdgpu_gfx940::acc201,565},
     {amdgpu_gfx940::acc202,566},
     {amdgpu_gfx940::acc203,567},
     {amdgpu_gfx940::acc204,568},
     {amdgpu_gfx940::acc205,569},
     {amdgpu_gfx940::acc206,570},
     {amdgpu_gfx940::acc207,571},
     {amdgpu_gfx940::acc208,572},
     {amdgpu_gfx940::acc209,573},
     {amdgpu_gfx940::acc210,574},
     {amdgpu_gfx940::acc211,575},
     {amdgpu_gfx940::acc212,576},
     {amdgpu_gfx940::acc213,577},
     {amdgpu_gfx940::acc214,578},
     {amdgpu_gfx940::acc215,579},
     {amdgpu_gfx940::acc216,580},
     {amdgpu_gfx940::acc217,581},
     {amdgpu_gfx940::acc218,582},
     {amdgpu_gfx940::acc219,583},
     {amdgpu_gfx940::acc220,584},
     {amdgpu_gfx940::acc221,585},
     {amdgpu_gfx940::acc222,586},
     {amdgpu_gfx940::acc223,587},
     {amdgpu_gfx940::acc224,588},
     {amdgpu_gfx940::acc225,589},
     {amdgpu_gfx940::acc226,590},
     {amdgpu_gfx940::acc227,591},
     {amdgpu_gfx940::acc228,592},
     {amdgpu_gfx940::acc229,593},
     {amdgpu_gfx940::acc230,594},
     {amdgpu_gfx940::acc231,595},
     {amdgpu_gfx940::acc232,596},
     {amdgpu_gfx940::acc233,597},
     {amdgpu_gfx940::acc234,598},
     {amdgpu_gfx940::acc235,599},
     {amdgpu_gfx940::acc236,600},
     {amdgpu_gfx940::acc237,601},
     {amdgpu_gfx940::acc238,602},
     {amdgpu_gfx940::acc239,603},
     {amdgpu_gfx940::acc240,604},
     {amdgpu_gfx940::acc241,605},
     {amdgpu_gfx940::acc242,606},
     {amdgpu_gfx940::acc243,607},
     {amdgpu_gfx940::acc244,608},
     {amdgpu_gfx940::acc245,609},
     {amdgpu_gfx940::acc246,610},
     {amdgpu_gfx940::acc247,611},
     {amdgpu_gfx940::acc248,612},
     {amdgpu_gfx940::acc249,613},
     {amdgpu_gfx940::acc250,614},
     {amdgpu_gfx940::acc251,615},
     {amdgpu_gfx940::acc252,616},
     {amdgpu_gfx940::acc253,617},
     {amdgpu_gfx940::acc254,618},
     {amdgpu_gfx940::acc255,619}};
    }
    return *mrmap;
}
}
}
